# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .toll_free_campaign_use_case_enum import TollFreeCampaignUseCaseEnum


class TollFreeCampaignSchemaUseCase(UniversalBaseModel):
    """
    Use case classification for the campaign.
    """

    summary: typing.Optional[str] = pydantic.Field(default=None)
    """
    Detailed summary of the use case explaining what messages will be sent and how users interact with the campaign. See the [Use Case Summary](/guides/campaigns/opt-in-compliance#use-case-summary) section for requirements.
    """

    value: typing.Optional[TollFreeCampaignUseCaseEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
