# This file was auto-generated by Fern from our API Definition.

import typing

VCardPhoneSchemaTypeItem = typing.Union[
    typing.Literal[
        "PREF", "WORK", "HOME", "VOICE", "FAX", "MSG", "CELL", "PAGER", "BBS", "MODEM", "CAR", "ISDN", "VIDEO"
    ],
    typing.Any,
]
