# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .basic_phone_information_location_country import BasicPhoneInformationLocationCountry


class BasicPhoneInformationLocation(UniversalBaseModel):
    """
    Geographic and political details where the phone number is registered.
    """

    country: BasicPhoneInformationLocationCountry = pydantic.Field()
    """
    Information about the country of registration.
    """

    place: str = pydantic.Field()
    """
    Location description including region, state/province, and city.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
