# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....core.serialization import FieldMetadata
from .rcs_campaign_help_keywords import RcsCampaignHelpKeywords
from .rcs_campaign_opt_in_keywords import RcsCampaignOptInKeywords
from .rcs_campaign_opt_out_keywords import RcsCampaignOptOutKeywords


class RcsCampaignKeywords(UniversalBaseModel):
    help: typing_extensions.Annotated[typing.Optional[RcsCampaignHelpKeywords], FieldMetadata(alias="HELP")] = None
    opt_in: typing_extensions.Annotated[typing.Optional[RcsCampaignOptInKeywords], FieldMetadata(alias="OPT_IN")] = None
    opt_out: typing_extensions.Annotated[typing.Optional[RcsCampaignOptOutKeywords], FieldMetadata(alias="OPT_OUT")] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
