# This file was auto-generated by Fern from our API Definition.

import typing

from .rich_cards_message import RichCardsMessage
from .rich_media_message import RichMediaMessage
from .rich_text_message import RichTextMessage

RichMessage = typing.Union[RichTextMessage, RichMediaMessage, RichCardsMessage]
