# This file was auto-generated by Fern from our API Definition.

import typing

TollFreeStatusEnum = typing.Union[
    typing.Literal[
        "WAITING_FOR_PROVIDER", "WAITING_FOR_CUSTOMER", "WAITING_FOR_TELECO", "IN_PROGRESS", "VERIFIED", "REJECTED"
    ],
    typing.Any,
]
