# This file was auto-generated by Fern from our API Definition.

import typing

DlcCampaignUseCaseEnum = typing.Union[
    typing.Literal[
        "ACCOUNT_NOTIFICATION",
        "AGENTS_FRANCHISES",
        "CARRIER_EXEMPT",
        "CHARITY",
        "CUSTOMER_CARE",
        "DELIVERY_NOTIFICATION",
        "EMERGENCY",
        "FRAUD_ALERT",
        "HIGHER_EDUCATION",
        "K12_EDUCATION",
        "LOW_VOLUME",
        "M2M",
        "MARKETING",
        "MIXED",
        "POLITICAL",
        "POLLING_VOTING",
        "PROXY",
        "PUBLIC_SERVICE_ANNOUNCEMENT",
        "SECURITY_ALERT",
        "SOCIAL",
        "SOLE_PROPRIETOR",
        "SWEEPSTAKE",
        "TRIAL",
        "TWO_FA",
        "UCAAS_HIGH",
        "UCAAS_LOW",
    ],
    typing.Any,
]
