# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import dlc, rcs, toll_free
    from .dlc import (
        DlcCampaignHelpKeywords,
        DlcCampaignKeywords,
        DlcCampaignLinks,
        DlcCampaignOptInKeywords,
        DlcCampaignOptOutKeywords,
        DlcCampaignOptions,
        DlcCampaignUseCase,
    )
    from .rcs import (
        RcsAgent,
        RcsAgentEmail,
        RcsAgentPhone,
        RcsAgentWebsite,
        RcsAutofillResponse,
        RcsCampaignHelpKeywords,
        RcsCampaignKeywords,
        RcsCampaignOptInKeywords,
        RcsCampaignOptOutKeywords,
        RcsCampaignTraffic,
        RcsLinks,
        RcsUseCase,
    )
    from .toll_free import (
        TollFreeAutofillResponse,
        TollFreeCampaignHelpKeywords,
        TollFreeCampaignKeywords,
        TollFreeCampaignLinks,
        TollFreeCampaignOptIn,
        TollFreeCampaignOptInKeywords,
        TollFreeCampaignOptions,
        TollFreeCampaignUseCase,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "DlcCampaignHelpKeywords": ".dlc",
    "DlcCampaignKeywords": ".dlc",
    "DlcCampaignLinks": ".dlc",
    "DlcCampaignOptInKeywords": ".dlc",
    "DlcCampaignOptOutKeywords": ".dlc",
    "DlcCampaignOptions": ".dlc",
    "DlcCampaignUseCase": ".dlc",
    "RcsAgent": ".rcs",
    "RcsAgentEmail": ".rcs",
    "RcsAgentPhone": ".rcs",
    "RcsAgentWebsite": ".rcs",
    "RcsAutofillResponse": ".rcs",
    "RcsCampaignHelpKeywords": ".rcs",
    "RcsCampaignKeywords": ".rcs",
    "RcsCampaignOptInKeywords": ".rcs",
    "RcsCampaignOptOutKeywords": ".rcs",
    "RcsCampaignTraffic": ".rcs",
    "RcsLinks": ".rcs",
    "RcsUseCase": ".rcs",
    "TollFreeAutofillResponse": ".toll_free",
    "TollFreeCampaignHelpKeywords": ".toll_free",
    "TollFreeCampaignKeywords": ".toll_free",
    "TollFreeCampaignLinks": ".toll_free",
    "TollFreeCampaignOptIn": ".toll_free",
    "TollFreeCampaignOptInKeywords": ".toll_free",
    "TollFreeCampaignOptions": ".toll_free",
    "TollFreeCampaignUseCase": ".toll_free",
    "dlc": ".",
    "rcs": ".",
    "toll_free": ".",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DlcCampaignHelpKeywords",
    "DlcCampaignKeywords",
    "DlcCampaignLinks",
    "DlcCampaignOptInKeywords",
    "DlcCampaignOptOutKeywords",
    "DlcCampaignOptions",
    "DlcCampaignUseCase",
    "RcsAgent",
    "RcsAgentEmail",
    "RcsAgentPhone",
    "RcsAgentWebsite",
    "RcsAutofillResponse",
    "RcsCampaignHelpKeywords",
    "RcsCampaignKeywords",
    "RcsCampaignOptInKeywords",
    "RcsCampaignOptOutKeywords",
    "RcsCampaignTraffic",
    "RcsLinks",
    "RcsUseCase",
    "TollFreeAutofillResponse",
    "TollFreeCampaignHelpKeywords",
    "TollFreeCampaignKeywords",
    "TollFreeCampaignLinks",
    "TollFreeCampaignOptIn",
    "TollFreeCampaignOptInKeywords",
    "TollFreeCampaignOptions",
    "TollFreeCampaignUseCase",
    "dlc",
    "rcs",
    "toll_free",
]
