# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.blast_details import BlastDetails
from ....types.scheduled_blast_details import ScheduledBlastDetails

BlastMmsResponse = typing.Union[BlastDetails, ScheduledBlastDetails]
