# This file was auto-generated by Fern from our API Definition.

import typing

from .message_event_mms_content import MessageEventMmsContent
from .message_event_rcs_button_data import MessageEventRcsButtonData
from .message_event_rcs_cards_content import MessageEventRcsCardsContent
from .message_event_rcs_location_data import MessageEventRcsLocationData
from .message_event_rcs_media_content import MessageEventRcsMediaContent
from .message_event_rcs_text_content import MessageEventRcsTextContent
from .message_event_sms_content import MessageEventSmsContent

MessageEventContent = typing.Union[
    MessageEventSmsContent,
    MessageEventMmsContent,
    MessageEventRcsTextContent,
    MessageEventRcsMediaContent,
    MessageEventRcsCardsContent,
    MessageEventRcsButtonData,
    MessageEventRcsLocationData,
]
