# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .blast_mms_options import BlastMmsOptions
    from .blast_mms_response import BlastMmsResponse
    from .blast_rcs_options import BlastRcsOptions
    from .blast_rcs_request_options_standalone_card import BlastRcsRequestOptionsStandaloneCard
    from .blast_rcs_request_options_standalone_card_image_alignment import (
        BlastRcsRequestOptionsStandaloneCardImageAlignment,
    )
    from .blast_rcs_request_options_standalone_card_orientation import BlastRcsRequestOptionsStandaloneCardOrientation
    from .blast_rcs_response import BlastRcsResponse
    from .blast_sms_options import BlastSmsOptions
    from .blast_sms_response import BlastSmsResponse
_dynamic_imports: typing.Dict[str, str] = {
    "BlastMmsOptions": ".blast_mms_options",
    "BlastMmsResponse": ".blast_mms_response",
    "BlastRcsOptions": ".blast_rcs_options",
    "BlastRcsRequestOptionsStandaloneCard": ".blast_rcs_request_options_standalone_card",
    "BlastRcsRequestOptionsStandaloneCardImageAlignment": ".blast_rcs_request_options_standalone_card_image_alignment",
    "BlastRcsRequestOptionsStandaloneCardOrientation": ".blast_rcs_request_options_standalone_card_orientation",
    "BlastRcsResponse": ".blast_rcs_response",
    "BlastSmsOptions": ".blast_sms_options",
    "BlastSmsResponse": ".blast_sms_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BlastMmsOptions",
    "BlastMmsResponse",
    "BlastRcsOptions",
    "BlastRcsRequestOptionsStandaloneCard",
    "BlastRcsRequestOptionsStandaloneCardImageAlignment",
    "BlastRcsRequestOptionsStandaloneCardOrientation",
    "BlastRcsResponse",
    "BlastSmsOptions",
    "BlastSmsResponse",
]
