# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .v_card_data_file_metadata import VCardDataFileMetadata


class VCardDataFile(UniversalBaseModel):
    """
    File associated to the contact.
    """

    url: str = pydantic.Field()
    """
    Presigned URL to download the contact card.
    """

    metadata: VCardDataFileMetadata = pydantic.Field()
    """
    Additional information about the download URL.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
