# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.advanced_phone_information import AdvancedPhoneInformation
from ...types.basic_phone_information import BasicPhoneInformation

PhoneNumbersGetResponse = typing.Union[BasicPhoneInformation, AdvancedPhoneInformation]
