# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class BlastDetails(UniversalBaseModel):
    """
    Response containing details about the scheduled blast.
    """

    blast_id: typing_extensions.Annotated[str, FieldMetadata(alias="blastId")] = pydantic.Field()
    """
    Unique identifier for the blast. This identifier is a string that always begins with the prefix `blast_`, for example: `blast_1234567890`.
    """

    audience_id: typing_extensions.Annotated[str, FieldMetadata(alias="audienceId")] = pydantic.Field()
    """
    The audience ID the blast was sent to. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.
    """

    total_recipients: typing_extensions.Annotated[int, FieldMetadata(alias="totalRecipients")] = pydantic.Field()
    """
    Total number of recipients in the audience.
    """

    total_messages: typing_extensions.Annotated[int, FieldMetadata(alias="totalMessages")] = pydantic.Field()
    """
    Total number of messages to be sent.
    """

    total_segments: typing_extensions.Annotated[int, FieldMetadata(alias="totalSegments")] = pydantic.Field()
    """
    Total number of message segments across all messages.
    """

    total_cost: typing_extensions.Annotated[float, FieldMetadata(alias="totalCost")] = pydantic.Field()
    """
    Total estimated cost of the blast. Calculated by multiplying the number of segments by the number of messages by the unit cost.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
