# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.scheduled_message import ScheduledMessage
from ....types.sent_sms_details import SentSmsDetails

SmsSendResponse = typing.Union[SentSmsDetails, ScheduledMessage]
