# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class DlcWithExtendedBrandAndStatusLinks(UniversalBaseModel):
    """
    Legal documentation links.
    """

    privacy_policy: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="privacyPolicy")] = (
        pydantic.Field(default=None)
    )
    """
    Privacy policy URL.
    """

    terms_of_service: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="termsOfService")] = (
        pydantic.Field(default=None)
    )
    """
    Terms of service URL.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
