# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AutofillDlcResponseKeywordsHelp(UniversalBaseModel):
    """
    Help keyword settings.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Response message for help keywords. See the [Keyword Response Messages](/guides/campaigns/opt-in-compliance#keyword-response-messages) section for requirements.
    """

    values: typing.List[str] = pydantic.Field()
    """
    Keywords that trigger help response.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
