# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AdvancedPhoneInformation,
        AdvancedPhoneInformationCarrier,
        AdvancedPhoneInformationContact,
        AdvancedPhoneInformationLocation,
        AdvancedPhoneInformationLocationCoordinates,
        AdvancedPhoneInformationLocationCountry,
        AdvancedPhoneInformationType,
        AdvancedPhoneInformationTypeRecommendation,
        Agent,
        AttachWebhookByIdParams,
        AttachWebhookParams,
        AttachWebhookResponseWebhook,
        AttachedPhoneNumberResult,
        AudienceCountOnly,
        AudienceWithPagination,
        AutofillCampaignParams,
        AutofillDlcCampaignResponse,
        AutofillDlcResponseKeywords,
        AutofillDlcResponseKeywordsHelp,
        AutofillDlcResponseKeywordsOptIn,
        AutofillDlcResponseKeywordsOptOut,
        AutofillDlcResponseLinks,
        AutofillDlcResponseOptions,
        AutofillDlcResponseUseCase,
        BadRequestErrorBody,
        BaseRichMessage,
        BasicPhoneInformation,
        BasicPhoneInformationContact,
        BasicPhoneInformationLocation,
        BasicPhoneInformationLocationCountry,
        BlastDetails,
        BrandStatus,
        BrandStatusEnum,
        ButtonClicked,
        ButtonClickedData,
        ButtonClickedDataButton,
        ButtonClickedDataButtonRaw,
        ButtonClickedDataButtonType,
        BuyResponseCapabilities,
        CampaignEnum,
        CampaignQuery,
        CampaignSubmissionResult,
        CampaignValidationResponseErrorsItem,
        CampaignValidationResult,
        CompanyEntityTypeEnum,
        CompanySectorEnum,
        CompanyTypeEnum,
        ConfiguredWebhook,
        Contact,
        ContactId,
        Conversation,
        ConversationByIdParams,
        ConversationByParticipantsParams,
        ConversationContact,
        ConversationList,
        ConversationSender,
        CreateAndAttachWebhookByUrlParams,
        CreateUrlOptions,
        DeleteAudienceResponse,
        DetachedPhoneNumberResult,
        DetachedWebhookInfo,
        DetailedPhoneNumberEnum,
        DlcAssignmentStatusEnum,
        DlcCampaignStatus,
        DlcCampaignUseCaseEnum,
        DlcCampaignWithExtendedBrandAndStatus,
        DlcWithExtendedBrandAndStatusKeywords,
        DlcWithExtendedBrandAndStatusKeywordsHelp,
        DlcWithExtendedBrandAndStatusKeywordsOptIn,
        DlcWithExtendedBrandAndStatusKeywordsOptOut,
        DlcWithExtendedBrandAndStatusLinks,
        DlcWithExtendedBrandAndStatusMnoBrandTier,
        DlcWithExtendedBrandAndStatusMnoTcrTier,
        DlcWithExtendedBrandAndStatusOptions,
        DlcWithExtendedBrandAndStatusUseCase,
        EnhancedContact,
        EnhancedContactItem,
        Error,
        ExtendedBrand,
        ExtendedBrandWithVetting,
        ExtendedRcsCampaign,
        GetConversationParams,
        GetDlcCampaignStatusResponseUpdates,
        GetTollFreeCampaignStatusResponseUpdates,
        LinkClickEvent,
        LocationShareAction,
        LocationShareActionData,
        Message,
        MessageContent,
        MessageEvent,
        MessageEventContent,
        MessageEventConversation,
        MessageEventDirection,
        MessageEventMmsContent,
        MessageEventRcsButtonData,
        MessageEventRcsCardsContent,
        MessageEventRcsCardsContentCardsItem,
        MessageEventRcsLocationData,
        MessageEventRcsMediaContent,
        MessageEventRcsTextContent,
        MessageEventSmsContent,
        MessageList,
        MessageMethodEnum,
        MessageProtocolEnum,
        MessageSchedule,
        MessageStatusEnum,
        MessageVolumeEnum,
        MessageWithReaction,
        MessageWithReactionDirection,
        MessagingProfileEnum,
        MmsContent,
        MmsValidationResponseSegments,
        MmsValidationResponseSegmentsValueItem,
        MmsValidationResult,
        NotFoundErrorBody,
        NumberFormat,
        OptInMethodEnum,
        OptionalBrandInfo,
        OptionalContact,
        OptionalContacts,
        Pagination,
        Phone,
        PhoneCapabilities,
        PhoneEnum,
        PhoneFeatureEnum,
        PhoneNumberCampaignAttachFailedItem,
        PhoneNumberCampaignAttachPhoneNumbersItem,
        PhoneNumberCampaignAttachPhoneNumbersItemCampaign,
        PhoneNumberCampaignDetachFailedItem,
        PhoneNumberCampaignDetachPhoneNumbersItem,
        PhoneNumberCampaignDetachPhoneNumbersItemCampaign,
        PhoneNumberCost,
        PhoneNumberDetails,
        PhoneNumberEnum,
        PhoneNumberRegion,
        PhoneNumberStatus,
        PhoneNumberStatusEnum,
        PinnacleFileUploadMetadata,
        PinnacleUrlConfig,
        ProfileStatusEnum,
        PurchasedNumber,
        RcsButtonCall,
        RcsButtonOpenUrl,
        RcsButtonOpenUrlWebviewMode,
        RcsButtonRequestUserLocation,
        RcsButtonScheduleEvent,
        RcsButtonSendLocation,
        RcsButtonSendLocationLatLong,
        RcsButtonTrigger,
        RcsCampaign,
        RcsCampaignSchemaAgent,
        RcsCampaignSchemaAgentEmailsItem,
        RcsCampaignSchemaAgentPhonesItem,
        RcsCampaignSchemaAgentWebsitesItem,
        RcsCampaignSchemaExtraAgent,
        RcsCampaignSchemaExtraAgentEmailsItem,
        RcsCampaignSchemaExtraAgentPhonesItem,
        RcsCampaignSchemaExtraAgentWebsitesItem,
        RcsCampaignSchemaExtraKeywords,
        RcsCampaignSchemaExtraKeywordsHelp,
        RcsCampaignSchemaExtraKeywordsOptIn,
        RcsCampaignSchemaExtraKeywordsOptOut,
        RcsCampaignSchemaExtraLinks,
        RcsCampaignSchemaExtraTraffic,
        RcsCampaignSchemaExtraUseCase,
        RcsCampaignSchemaKeywords,
        RcsCampaignSchemaKeywordsHelp,
        RcsCampaignSchemaKeywordsOptIn,
        RcsCampaignSchemaKeywordsOptOut,
        RcsCampaignSchemaLinks,
        RcsCampaignSchemaTraffic,
        RcsCampaignSchemaUseCase,
        RcsCampaignStatus,
        RcsCampaignUseCaseEnum,
        RcsCapabilitiesResult,
        RcsCapability,
        RcsCapabilityActions,
        RcsCapabilityCards,
        RcsCardsContent,
        RcsCardsContentCardsItem,
        RcsContent,
        RcsLinkResult,
        RcsMediaContent,
        RcsMediaDetailsContent,
        RcsMessagingTypeEnum,
        RcsValidateContent,
        RcsValidateContentMedia,
        RcsValidationResult,
        RcsWhitelistResponse,
        ReactionResult,
        RefreshedFile,
        RichButton,
        RichButton_Call,
        RichButton_OpenUrl,
        RichButton_RequestUserLocation,
        RichButton_ScheduleEvent,
        RichButton_SendLocation,
        RichButton_Trigger,
        RichCard,
        RichCards,
        RichCardsMessage,
        RichMediaMessage,
        RichMessage,
        RichStandaloneCardOptions,
        RichText,
        RichTextMessage,
        ScheduleCancelResult,
        ScheduledBlastDetails,
        ScheduledBlastResponseConfig,
        ScheduledMessage,
        ScheduledSendResponseConfig,
        SendRcsCardOptionsStandaloneCardImageAlignment,
        SendRcsCardOptionsStandaloneCardOrientation,
        SendRichCardsOptions,
        SendRichMessageOptions,
        SendSmsResponseSegments,
        SendSmsResponseSegmentsEncoding,
        SendTypingIndicatorResponse,
        Sender,
        SentMmsDetails,
        SentRichMessage,
        SentSmsDetails,
        ShortenedUrl,
        ShortenedUrlWithClickData,
        SmsContent,
        SmsValidationResponseSegments,
        SmsValidationResponseSegmentsGsm7,
        SmsValidationResponseSegmentsUtf16,
        SmsValidationResponseTotal,
        SmsValidationResult,
        SubUseCaseEnum,
        SubmissionResults,
        SuccessfulConversationUpdate,
        TollFreeCampaign,
        TollFreeCampaignSchemaKeywords,
        TollFreeCampaignSchemaKeywordsHelp,
        TollFreeCampaignSchemaKeywordsOptIn,
        TollFreeCampaignSchemaLinks,
        TollFreeCampaignSchemaOptIn,
        TollFreeCampaignSchemaOptions,
        TollFreeCampaignSchemaUseCase,
        TollFreeCampaignStatus,
        TollFreeCampaignUseCaseEnum,
        TollFreeCampaignWithExtendedBrandAndStatus,
        TollFreeStatusEnum,
        TollFreeWithExtendedBrandAndStatusKeywords,
        TollFreeWithExtendedBrandAndStatusKeywordsHelp,
        TollFreeWithExtendedBrandAndStatusKeywordsOptIn,
        TollFreeWithExtendedBrandAndStatusLinks,
        TollFreeWithExtendedBrandAndStatusOptIn,
        TollFreeWithExtendedBrandAndStatusOptions,
        TollFreeWithExtendedBrandAndStatusUseCase,
        Tracking,
        UpdatedContactId,
        UploadResults,
        UserEvent,
        UserEventConversation,
        VCardAddressSchemaTypeItem,
        VCardData,
        VCardDataFile,
        VCardDataFileMetadata,
        VCardEmailSchemaTypeItem,
        VCardGeo,
        VCardName,
        VCardOrganization,
        VCardPhoneSchemaTypeItem,
        ValidateCampaignParams,
        ValidationErrorDetails,
        ValidationResults,
        Vcard,
        VcardAddress,
        VcardContent,
        VcardEmail,
        VcardPhone,
        VcardResource,
        VettingFeedback,
        VettingHistory,
        VettingHistoryVettingStatus,
        VettingResults,
        WebhookEventEnum,
        WebhookResult,
        Webhooks,
        ZodError,
    )
    from .errors import (
        BadRequestError,
        InternalServerError,
        NotFoundError,
        NotImplementedError,
        PaymentRequiredError,
        UnauthorizedError,
    )
    from . import (
        audiences,
        brands,
        campaigns,
        contacts,
        conversations,
        messages,
        phone_numbers,
        rcs,
        status,
        tools,
        webhooks,
    )
    from .audiences import AudiencesGetResponse
    from .brands import (
        AutofillBrandOptions,
        UpsertBrandSchemaContact,
        UpsertBrandSchemaEntityType,
        UpsertBrandSchemaSector,
        UpsertBrandSchemaType,
    )
    from .client import AsyncPinnacle, Pinnacle
    from .conversations import (
        ConversationsListMessagesRequestDirection,
        ConversationsListMessagesRequestSortOrder,
        ConversationsListMessagesRequestStatus,
        ConversationsListMessagesRequestType,
    )
    from .environment import PinnacleEnvironment
    from .messages import ReactMessageOptions
    from .phone_numbers import (
        EnhancedContactInfo,
        PhoneDetailsSchemaLevel,
        PhoneNumbersGetResponse,
        RetrievePhoneNumberDetailsOptions,
        SearchPhoneNumberByDigits,
        SearchPhoneNumberByLocation,
        SearchPhoneNumberOptions,
    )
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AdvancedPhoneInformation": ".types",
    "AdvancedPhoneInformationCarrier": ".types",
    "AdvancedPhoneInformationContact": ".types",
    "AdvancedPhoneInformationLocation": ".types",
    "AdvancedPhoneInformationLocationCoordinates": ".types",
    "AdvancedPhoneInformationLocationCountry": ".types",
    "AdvancedPhoneInformationType": ".types",
    "AdvancedPhoneInformationTypeRecommendation": ".types",
    "Agent": ".types",
    "AsyncPinnacle": ".client",
    "AttachWebhookByIdParams": ".types",
    "AttachWebhookParams": ".types",
    "AttachWebhookResponseWebhook": ".types",
    "AttachedPhoneNumberResult": ".types",
    "AudienceCountOnly": ".types",
    "AudienceWithPagination": ".types",
    "AudiencesGetResponse": ".audiences",
    "AutofillBrandOptions": ".brands",
    "AutofillCampaignParams": ".types",
    "AutofillDlcCampaignResponse": ".types",
    "AutofillDlcResponseKeywords": ".types",
    "AutofillDlcResponseKeywordsHelp": ".types",
    "AutofillDlcResponseKeywordsOptIn": ".types",
    "AutofillDlcResponseKeywordsOptOut": ".types",
    "AutofillDlcResponseLinks": ".types",
    "AutofillDlcResponseOptions": ".types",
    "AutofillDlcResponseUseCase": ".types",
    "BadRequestError": ".errors",
    "BadRequestErrorBody": ".types",
    "BaseRichMessage": ".types",
    "BasicPhoneInformation": ".types",
    "BasicPhoneInformationContact": ".types",
    "BasicPhoneInformationLocation": ".types",
    "BasicPhoneInformationLocationCountry": ".types",
    "BlastDetails": ".types",
    "BrandStatus": ".types",
    "BrandStatusEnum": ".types",
    "ButtonClicked": ".types",
    "ButtonClickedData": ".types",
    "ButtonClickedDataButton": ".types",
    "ButtonClickedDataButtonRaw": ".types",
    "ButtonClickedDataButtonType": ".types",
    "BuyResponseCapabilities": ".types",
    "CampaignEnum": ".types",
    "CampaignQuery": ".types",
    "CampaignSubmissionResult": ".types",
    "CampaignValidationResponseErrorsItem": ".types",
    "CampaignValidationResult": ".types",
    "CompanyEntityTypeEnum": ".types",
    "CompanySectorEnum": ".types",
    "CompanyTypeEnum": ".types",
    "ConfiguredWebhook": ".types",
    "Contact": ".types",
    "ContactId": ".types",
    "Conversation": ".types",
    "ConversationByIdParams": ".types",
    "ConversationByParticipantsParams": ".types",
    "ConversationContact": ".types",
    "ConversationList": ".types",
    "ConversationSender": ".types",
    "ConversationsListMessagesRequestDirection": ".conversations",
    "ConversationsListMessagesRequestSortOrder": ".conversations",
    "ConversationsListMessagesRequestStatus": ".conversations",
    "ConversationsListMessagesRequestType": ".conversations",
    "CreateAndAttachWebhookByUrlParams": ".types",
    "CreateUrlOptions": ".types",
    "DeleteAudienceResponse": ".types",
    "DetachedPhoneNumberResult": ".types",
    "DetachedWebhookInfo": ".types",
    "DetailedPhoneNumberEnum": ".types",
    "DlcAssignmentStatusEnum": ".types",
    "DlcCampaignStatus": ".types",
    "DlcCampaignUseCaseEnum": ".types",
    "DlcCampaignWithExtendedBrandAndStatus": ".types",
    "DlcWithExtendedBrandAndStatusKeywords": ".types",
    "DlcWithExtendedBrandAndStatusKeywordsHelp": ".types",
    "DlcWithExtendedBrandAndStatusKeywordsOptIn": ".types",
    "DlcWithExtendedBrandAndStatusKeywordsOptOut": ".types",
    "DlcWithExtendedBrandAndStatusLinks": ".types",
    "DlcWithExtendedBrandAndStatusMnoBrandTier": ".types",
    "DlcWithExtendedBrandAndStatusMnoTcrTier": ".types",
    "DlcWithExtendedBrandAndStatusOptions": ".types",
    "DlcWithExtendedBrandAndStatusUseCase": ".types",
    "EnhancedContact": ".types",
    "EnhancedContactInfo": ".phone_numbers",
    "EnhancedContactItem": ".types",
    "Error": ".types",
    "ExtendedBrand": ".types",
    "ExtendedBrandWithVetting": ".types",
    "ExtendedRcsCampaign": ".types",
    "GetConversationParams": ".types",
    "GetDlcCampaignStatusResponseUpdates": ".types",
    "GetTollFreeCampaignStatusResponseUpdates": ".types",
    "InternalServerError": ".errors",
    "LinkClickEvent": ".types",
    "LocationShareAction": ".types",
    "LocationShareActionData": ".types",
    "Message": ".types",
    "MessageContent": ".types",
    "MessageEvent": ".types",
    "MessageEventContent": ".types",
    "MessageEventConversation": ".types",
    "MessageEventDirection": ".types",
    "MessageEventMmsContent": ".types",
    "MessageEventRcsButtonData": ".types",
    "MessageEventRcsCardsContent": ".types",
    "MessageEventRcsCardsContentCardsItem": ".types",
    "MessageEventRcsLocationData": ".types",
    "MessageEventRcsMediaContent": ".types",
    "MessageEventRcsTextContent": ".types",
    "MessageEventSmsContent": ".types",
    "MessageList": ".types",
    "MessageMethodEnum": ".types",
    "MessageProtocolEnum": ".types",
    "MessageSchedule": ".types",
    "MessageStatusEnum": ".types",
    "MessageVolumeEnum": ".types",
    "MessageWithReaction": ".types",
    "MessageWithReactionDirection": ".types",
    "MessagingProfileEnum": ".types",
    "MmsContent": ".types",
    "MmsValidationResponseSegments": ".types",
    "MmsValidationResponseSegmentsValueItem": ".types",
    "MmsValidationResult": ".types",
    "NotFoundError": ".errors",
    "NotFoundErrorBody": ".types",
    "NotImplementedError": ".errors",
    "NumberFormat": ".types",
    "OptInMethodEnum": ".types",
    "OptionalBrandInfo": ".types",
    "OptionalContact": ".types",
    "OptionalContacts": ".types",
    "Pagination": ".types",
    "PaymentRequiredError": ".errors",
    "Phone": ".types",
    "PhoneCapabilities": ".types",
    "PhoneDetailsSchemaLevel": ".phone_numbers",
    "PhoneEnum": ".types",
    "PhoneFeatureEnum": ".types",
    "PhoneNumberCampaignAttachFailedItem": ".types",
    "PhoneNumberCampaignAttachPhoneNumbersItem": ".types",
    "PhoneNumberCampaignAttachPhoneNumbersItemCampaign": ".types",
    "PhoneNumberCampaignDetachFailedItem": ".types",
    "PhoneNumberCampaignDetachPhoneNumbersItem": ".types",
    "PhoneNumberCampaignDetachPhoneNumbersItemCampaign": ".types",
    "PhoneNumberCost": ".types",
    "PhoneNumberDetails": ".types",
    "PhoneNumberEnum": ".types",
    "PhoneNumberRegion": ".types",
    "PhoneNumberStatus": ".types",
    "PhoneNumberStatusEnum": ".types",
    "PhoneNumbersGetResponse": ".phone_numbers",
    "Pinnacle": ".client",
    "PinnacleEnvironment": ".environment",
    "PinnacleFileUploadMetadata": ".types",
    "PinnacleUrlConfig": ".types",
    "ProfileStatusEnum": ".types",
    "PurchasedNumber": ".types",
    "RcsButtonCall": ".types",
    "RcsButtonOpenUrl": ".types",
    "RcsButtonOpenUrlWebviewMode": ".types",
    "RcsButtonRequestUserLocation": ".types",
    "RcsButtonScheduleEvent": ".types",
    "RcsButtonSendLocation": ".types",
    "RcsButtonSendLocationLatLong": ".types",
    "RcsButtonTrigger": ".types",
    "RcsCampaign": ".types",
    "RcsCampaignSchemaAgent": ".types",
    "RcsCampaignSchemaAgentEmailsItem": ".types",
    "RcsCampaignSchemaAgentPhonesItem": ".types",
    "RcsCampaignSchemaAgentWebsitesItem": ".types",
    "RcsCampaignSchemaExtraAgent": ".types",
    "RcsCampaignSchemaExtraAgentEmailsItem": ".types",
    "RcsCampaignSchemaExtraAgentPhonesItem": ".types",
    "RcsCampaignSchemaExtraAgentWebsitesItem": ".types",
    "RcsCampaignSchemaExtraKeywords": ".types",
    "RcsCampaignSchemaExtraKeywordsHelp": ".types",
    "RcsCampaignSchemaExtraKeywordsOptIn": ".types",
    "RcsCampaignSchemaExtraKeywordsOptOut": ".types",
    "RcsCampaignSchemaExtraLinks": ".types",
    "RcsCampaignSchemaExtraTraffic": ".types",
    "RcsCampaignSchemaExtraUseCase": ".types",
    "RcsCampaignSchemaKeywords": ".types",
    "RcsCampaignSchemaKeywordsHelp": ".types",
    "RcsCampaignSchemaKeywordsOptIn": ".types",
    "RcsCampaignSchemaKeywordsOptOut": ".types",
    "RcsCampaignSchemaLinks": ".types",
    "RcsCampaignSchemaTraffic": ".types",
    "RcsCampaignSchemaUseCase": ".types",
    "RcsCampaignStatus": ".types",
    "RcsCampaignUseCaseEnum": ".types",
    "RcsCapabilitiesResult": ".types",
    "RcsCapability": ".types",
    "RcsCapabilityActions": ".types",
    "RcsCapabilityCards": ".types",
    "RcsCardsContent": ".types",
    "RcsCardsContentCardsItem": ".types",
    "RcsContent": ".types",
    "RcsLinkResult": ".types",
    "RcsMediaContent": ".types",
    "RcsMediaDetailsContent": ".types",
    "RcsMessagingTypeEnum": ".types",
    "RcsValidateContent": ".types",
    "RcsValidateContentMedia": ".types",
    "RcsValidationResult": ".types",
    "RcsWhitelistResponse": ".types",
    "ReactMessageOptions": ".messages",
    "ReactionResult": ".types",
    "RefreshedFile": ".types",
    "RetrievePhoneNumberDetailsOptions": ".phone_numbers",
    "RichButton": ".types",
    "RichButton_Call": ".types",
    "RichButton_OpenUrl": ".types",
    "RichButton_RequestUserLocation": ".types",
    "RichButton_ScheduleEvent": ".types",
    "RichButton_SendLocation": ".types",
    "RichButton_Trigger": ".types",
    "RichCard": ".types",
    "RichCards": ".types",
    "RichCardsMessage": ".types",
    "RichMediaMessage": ".types",
    "RichMessage": ".types",
    "RichStandaloneCardOptions": ".types",
    "RichText": ".types",
    "RichTextMessage": ".types",
    "ScheduleCancelResult": ".types",
    "ScheduledBlastDetails": ".types",
    "ScheduledBlastResponseConfig": ".types",
    "ScheduledMessage": ".types",
    "ScheduledSendResponseConfig": ".types",
    "SearchPhoneNumberByDigits": ".phone_numbers",
    "SearchPhoneNumberByLocation": ".phone_numbers",
    "SearchPhoneNumberOptions": ".phone_numbers",
    "SendRcsCardOptionsStandaloneCardImageAlignment": ".types",
    "SendRcsCardOptionsStandaloneCardOrientation": ".types",
    "SendRichCardsOptions": ".types",
    "SendRichMessageOptions": ".types",
    "SendSmsResponseSegments": ".types",
    "SendSmsResponseSegmentsEncoding": ".types",
    "SendTypingIndicatorResponse": ".types",
    "Sender": ".types",
    "SentMmsDetails": ".types",
    "SentRichMessage": ".types",
    "SentSmsDetails": ".types",
    "ShortenedUrl": ".types",
    "ShortenedUrlWithClickData": ".types",
    "SmsContent": ".types",
    "SmsValidationResponseSegments": ".types",
    "SmsValidationResponseSegmentsGsm7": ".types",
    "SmsValidationResponseSegmentsUtf16": ".types",
    "SmsValidationResponseTotal": ".types",
    "SmsValidationResult": ".types",
    "SubUseCaseEnum": ".types",
    "SubmissionResults": ".types",
    "SuccessfulConversationUpdate": ".types",
    "TollFreeCampaign": ".types",
    "TollFreeCampaignSchemaKeywords": ".types",
    "TollFreeCampaignSchemaKeywordsHelp": ".types",
    "TollFreeCampaignSchemaKeywordsOptIn": ".types",
    "TollFreeCampaignSchemaLinks": ".types",
    "TollFreeCampaignSchemaOptIn": ".types",
    "TollFreeCampaignSchemaOptions": ".types",
    "TollFreeCampaignSchemaUseCase": ".types",
    "TollFreeCampaignStatus": ".types",
    "TollFreeCampaignUseCaseEnum": ".types",
    "TollFreeCampaignWithExtendedBrandAndStatus": ".types",
    "TollFreeStatusEnum": ".types",
    "TollFreeWithExtendedBrandAndStatusKeywords": ".types",
    "TollFreeWithExtendedBrandAndStatusKeywordsHelp": ".types",
    "TollFreeWithExtendedBrandAndStatusKeywordsOptIn": ".types",
    "TollFreeWithExtendedBrandAndStatusLinks": ".types",
    "TollFreeWithExtendedBrandAndStatusOptIn": ".types",
    "TollFreeWithExtendedBrandAndStatusOptions": ".types",
    "TollFreeWithExtendedBrandAndStatusUseCase": ".types",
    "Tracking": ".types",
    "UnauthorizedError": ".errors",
    "UpdatedContactId": ".types",
    "UploadResults": ".types",
    "UpsertBrandSchemaContact": ".brands",
    "UpsertBrandSchemaEntityType": ".brands",
    "UpsertBrandSchemaSector": ".brands",
    "UpsertBrandSchemaType": ".brands",
    "UserEvent": ".types",
    "UserEventConversation": ".types",
    "VCardAddressSchemaTypeItem": ".types",
    "VCardData": ".types",
    "VCardDataFile": ".types",
    "VCardDataFileMetadata": ".types",
    "VCardEmailSchemaTypeItem": ".types",
    "VCardGeo": ".types",
    "VCardName": ".types",
    "VCardOrganization": ".types",
    "VCardPhoneSchemaTypeItem": ".types",
    "ValidateCampaignParams": ".types",
    "ValidationErrorDetails": ".types",
    "ValidationResults": ".types",
    "Vcard": ".types",
    "VcardAddress": ".types",
    "VcardContent": ".types",
    "VcardEmail": ".types",
    "VcardPhone": ".types",
    "VcardResource": ".types",
    "VettingFeedback": ".types",
    "VettingHistory": ".types",
    "VettingHistoryVettingStatus": ".types",
    "VettingResults": ".types",
    "WebhookEventEnum": ".types",
    "WebhookResult": ".types",
    "Webhooks": ".types",
    "ZodError": ".types",
    "__version__": ".version",
    "audiences": ".",
    "brands": ".",
    "campaigns": ".",
    "contacts": ".",
    "conversations": ".",
    "messages": ".",
    "phone_numbers": ".",
    "rcs": ".",
    "status": ".",
    "tools": ".",
    "webhooks": ".",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AdvancedPhoneInformation",
    "AdvancedPhoneInformationCarrier",
    "AdvancedPhoneInformationContact",
    "AdvancedPhoneInformationLocation",
    "AdvancedPhoneInformationLocationCoordinates",
    "AdvancedPhoneInformationLocationCountry",
    "AdvancedPhoneInformationType",
    "AdvancedPhoneInformationTypeRecommendation",
    "Agent",
    "AsyncPinnacle",
    "AttachWebhookByIdParams",
    "AttachWebhookParams",
    "AttachWebhookResponseWebhook",
    "AttachedPhoneNumberResult",
    "AudienceCountOnly",
    "AudienceWithPagination",
    "AudiencesGetResponse",
    "AutofillBrandOptions",
    "AutofillCampaignParams",
    "AutofillDlcCampaignResponse",
    "AutofillDlcResponseKeywords",
    "AutofillDlcResponseKeywordsHelp",
    "AutofillDlcResponseKeywordsOptIn",
    "AutofillDlcResponseKeywordsOptOut",
    "AutofillDlcResponseLinks",
    "AutofillDlcResponseOptions",
    "AutofillDlcResponseUseCase",
    "BadRequestError",
    "BadRequestErrorBody",
    "BaseRichMessage",
    "BasicPhoneInformation",
    "BasicPhoneInformationContact",
    "BasicPhoneInformationLocation",
    "BasicPhoneInformationLocationCountry",
    "BlastDetails",
    "BrandStatus",
    "BrandStatusEnum",
    "ButtonClicked",
    "ButtonClickedData",
    "ButtonClickedDataButton",
    "ButtonClickedDataButtonRaw",
    "ButtonClickedDataButtonType",
    "BuyResponseCapabilities",
    "CampaignEnum",
    "CampaignQuery",
    "CampaignSubmissionResult",
    "CampaignValidationResponseErrorsItem",
    "CampaignValidationResult",
    "CompanyEntityTypeEnum",
    "CompanySectorEnum",
    "CompanyTypeEnum",
    "ConfiguredWebhook",
    "Contact",
    "ContactId",
    "Conversation",
    "ConversationByIdParams",
    "ConversationByParticipantsParams",
    "ConversationContact",
    "ConversationList",
    "ConversationSender",
    "ConversationsListMessagesRequestDirection",
    "ConversationsListMessagesRequestSortOrder",
    "ConversationsListMessagesRequestStatus",
    "ConversationsListMessagesRequestType",
    "CreateAndAttachWebhookByUrlParams",
    "CreateUrlOptions",
    "DeleteAudienceResponse",
    "DetachedPhoneNumberResult",
    "DetachedWebhookInfo",
    "DetailedPhoneNumberEnum",
    "DlcAssignmentStatusEnum",
    "DlcCampaignStatus",
    "DlcCampaignUseCaseEnum",
    "DlcCampaignWithExtendedBrandAndStatus",
    "DlcWithExtendedBrandAndStatusKeywords",
    "DlcWithExtendedBrandAndStatusKeywordsHelp",
    "DlcWithExtendedBrandAndStatusKeywordsOptIn",
    "DlcWithExtendedBrandAndStatusKeywordsOptOut",
    "DlcWithExtendedBrandAndStatusLinks",
    "DlcWithExtendedBrandAndStatusMnoBrandTier",
    "DlcWithExtendedBrandAndStatusMnoTcrTier",
    "DlcWithExtendedBrandAndStatusOptions",
    "DlcWithExtendedBrandAndStatusUseCase",
    "EnhancedContact",
    "EnhancedContactInfo",
    "EnhancedContactItem",
    "Error",
    "ExtendedBrand",
    "ExtendedBrandWithVetting",
    "ExtendedRcsCampaign",
    "GetConversationParams",
    "GetDlcCampaignStatusResponseUpdates",
    "GetTollFreeCampaignStatusResponseUpdates",
    "InternalServerError",
    "LinkClickEvent",
    "LocationShareAction",
    "LocationShareActionData",
    "Message",
    "MessageContent",
    "MessageEvent",
    "MessageEventContent",
    "MessageEventConversation",
    "MessageEventDirection",
    "MessageEventMmsContent",
    "MessageEventRcsButtonData",
    "MessageEventRcsCardsContent",
    "MessageEventRcsCardsContentCardsItem",
    "MessageEventRcsLocationData",
    "MessageEventRcsMediaContent",
    "MessageEventRcsTextContent",
    "MessageEventSmsContent",
    "MessageList",
    "MessageMethodEnum",
    "MessageProtocolEnum",
    "MessageSchedule",
    "MessageStatusEnum",
    "MessageVolumeEnum",
    "MessageWithReaction",
    "MessageWithReactionDirection",
    "MessagingProfileEnum",
    "MmsContent",
    "MmsValidationResponseSegments",
    "MmsValidationResponseSegmentsValueItem",
    "MmsValidationResult",
    "NotFoundError",
    "NotFoundErrorBody",
    "NotImplementedError",
    "NumberFormat",
    "OptInMethodEnum",
    "OptionalBrandInfo",
    "OptionalContact",
    "OptionalContacts",
    "Pagination",
    "PaymentRequiredError",
    "Phone",
    "PhoneCapabilities",
    "PhoneDetailsSchemaLevel",
    "PhoneEnum",
    "PhoneFeatureEnum",
    "PhoneNumberCampaignAttachFailedItem",
    "PhoneNumberCampaignAttachPhoneNumbersItem",
    "PhoneNumberCampaignAttachPhoneNumbersItemCampaign",
    "PhoneNumberCampaignDetachFailedItem",
    "PhoneNumberCampaignDetachPhoneNumbersItem",
    "PhoneNumberCampaignDetachPhoneNumbersItemCampaign",
    "PhoneNumberCost",
    "PhoneNumberDetails",
    "PhoneNumberEnum",
    "PhoneNumberRegion",
    "PhoneNumberStatus",
    "PhoneNumberStatusEnum",
    "PhoneNumbersGetResponse",
    "Pinnacle",
    "PinnacleEnvironment",
    "PinnacleFileUploadMetadata",
    "PinnacleUrlConfig",
    "ProfileStatusEnum",
    "PurchasedNumber",
    "RcsButtonCall",
    "RcsButtonOpenUrl",
    "RcsButtonOpenUrlWebviewMode",
    "RcsButtonRequestUserLocation",
    "RcsButtonScheduleEvent",
    "RcsButtonSendLocation",
    "RcsButtonSendLocationLatLong",
    "RcsButtonTrigger",
    "RcsCampaign",
    "RcsCampaignSchemaAgent",
    "RcsCampaignSchemaAgentEmailsItem",
    "RcsCampaignSchemaAgentPhonesItem",
    "RcsCampaignSchemaAgentWebsitesItem",
    "RcsCampaignSchemaExtraAgent",
    "RcsCampaignSchemaExtraAgentEmailsItem",
    "RcsCampaignSchemaExtraAgentPhonesItem",
    "RcsCampaignSchemaExtraAgentWebsitesItem",
    "RcsCampaignSchemaExtraKeywords",
    "RcsCampaignSchemaExtraKeywordsHelp",
    "RcsCampaignSchemaExtraKeywordsOptIn",
    "RcsCampaignSchemaExtraKeywordsOptOut",
    "RcsCampaignSchemaExtraLinks",
    "RcsCampaignSchemaExtraTraffic",
    "RcsCampaignSchemaExtraUseCase",
    "RcsCampaignSchemaKeywords",
    "RcsCampaignSchemaKeywordsHelp",
    "RcsCampaignSchemaKeywordsOptIn",
    "RcsCampaignSchemaKeywordsOptOut",
    "RcsCampaignSchemaLinks",
    "RcsCampaignSchemaTraffic",
    "RcsCampaignSchemaUseCase",
    "RcsCampaignStatus",
    "RcsCampaignUseCaseEnum",
    "RcsCapabilitiesResult",
    "RcsCapability",
    "RcsCapabilityActions",
    "RcsCapabilityCards",
    "RcsCardsContent",
    "RcsCardsContentCardsItem",
    "RcsContent",
    "RcsLinkResult",
    "RcsMediaContent",
    "RcsMediaDetailsContent",
    "RcsMessagingTypeEnum",
    "RcsValidateContent",
    "RcsValidateContentMedia",
    "RcsValidationResult",
    "RcsWhitelistResponse",
    "ReactMessageOptions",
    "ReactionResult",
    "RefreshedFile",
    "RetrievePhoneNumberDetailsOptions",
    "RichButton",
    "RichButton_Call",
    "RichButton_OpenUrl",
    "RichButton_RequestUserLocation",
    "RichButton_ScheduleEvent",
    "RichButton_SendLocation",
    "RichButton_Trigger",
    "RichCard",
    "RichCards",
    "RichCardsMessage",
    "RichMediaMessage",
    "RichMessage",
    "RichStandaloneCardOptions",
    "RichText",
    "RichTextMessage",
    "ScheduleCancelResult",
    "ScheduledBlastDetails",
    "ScheduledBlastResponseConfig",
    "ScheduledMessage",
    "ScheduledSendResponseConfig",
    "SearchPhoneNumberByDigits",
    "SearchPhoneNumberByLocation",
    "SearchPhoneNumberOptions",
    "SendRcsCardOptionsStandaloneCardImageAlignment",
    "SendRcsCardOptionsStandaloneCardOrientation",
    "SendRichCardsOptions",
    "SendRichMessageOptions",
    "SendSmsResponseSegments",
    "SendSmsResponseSegmentsEncoding",
    "SendTypingIndicatorResponse",
    "Sender",
    "SentMmsDetails",
    "SentRichMessage",
    "SentSmsDetails",
    "ShortenedUrl",
    "ShortenedUrlWithClickData",
    "SmsContent",
    "SmsValidationResponseSegments",
    "SmsValidationResponseSegmentsGsm7",
    "SmsValidationResponseSegmentsUtf16",
    "SmsValidationResponseTotal",
    "SmsValidationResult",
    "SubUseCaseEnum",
    "SubmissionResults",
    "SuccessfulConversationUpdate",
    "TollFreeCampaign",
    "TollFreeCampaignSchemaKeywords",
    "TollFreeCampaignSchemaKeywordsHelp",
    "TollFreeCampaignSchemaKeywordsOptIn",
    "TollFreeCampaignSchemaLinks",
    "TollFreeCampaignSchemaOptIn",
    "TollFreeCampaignSchemaOptions",
    "TollFreeCampaignSchemaUseCase",
    "TollFreeCampaignStatus",
    "TollFreeCampaignUseCaseEnum",
    "TollFreeCampaignWithExtendedBrandAndStatus",
    "TollFreeStatusEnum",
    "TollFreeWithExtendedBrandAndStatusKeywords",
    "TollFreeWithExtendedBrandAndStatusKeywordsHelp",
    "TollFreeWithExtendedBrandAndStatusKeywordsOptIn",
    "TollFreeWithExtendedBrandAndStatusLinks",
    "TollFreeWithExtendedBrandAndStatusOptIn",
    "TollFreeWithExtendedBrandAndStatusOptions",
    "TollFreeWithExtendedBrandAndStatusUseCase",
    "Tracking",
    "UnauthorizedError",
    "UpdatedContactId",
    "UploadResults",
    "UpsertBrandSchemaContact",
    "UpsertBrandSchemaEntityType",
    "UpsertBrandSchemaSector",
    "UpsertBrandSchemaType",
    "UserEvent",
    "UserEventConversation",
    "VCardAddressSchemaTypeItem",
    "VCardData",
    "VCardDataFile",
    "VCardDataFileMetadata",
    "VCardEmailSchemaTypeItem",
    "VCardGeo",
    "VCardName",
    "VCardOrganization",
    "VCardPhoneSchemaTypeItem",
    "ValidateCampaignParams",
    "ValidationErrorDetails",
    "ValidationResults",
    "Vcard",
    "VcardAddress",
    "VcardContent",
    "VcardEmail",
    "VcardPhone",
    "VcardResource",
    "VettingFeedback",
    "VettingHistory",
    "VettingHistoryVettingStatus",
    "VettingResults",
    "WebhookEventEnum",
    "WebhookResult",
    "Webhooks",
    "ZodError",
    "__version__",
    "audiences",
    "brands",
    "campaigns",
    "contacts",
    "conversations",
    "messages",
    "phone_numbers",
    "rcs",
    "status",
    "tools",
    "webhooks",
]
