# This file was auto-generated by Fern from our API Definition.

import typing

from .button_clicked_data import ButtonClickedData
from .location_share_action import LocationShareAction

ButtonClicked = typing.Union[ButtonClickedData, LocationShareAction]
