# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .rcs_campaign_schema_extra_keywords_help import RcsCampaignSchemaExtraKeywordsHelp
from .rcs_campaign_schema_extra_keywords_opt_in import RcsCampaignSchemaExtraKeywordsOptIn
from .rcs_campaign_schema_extra_keywords_opt_out import RcsCampaignSchemaExtraKeywordsOptOut


class RcsCampaignSchemaExtraKeywords(UniversalBaseModel):
    help: typing_extensions.Annotated[
        typing.Optional[RcsCampaignSchemaExtraKeywordsHelp], FieldMetadata(alias="HELP")
    ] = None
    opt_in: typing_extensions.Annotated[
        typing.Optional[RcsCampaignSchemaExtraKeywordsOptIn], FieldMetadata(alias="OPT_IN")
    ] = None
    opt_out: typing_extensions.Annotated[
        typing.Optional[RcsCampaignSchemaExtraKeywordsOptOut], FieldMetadata(alias="OPT_OUT")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
