# This file was auto-generated by Fern from our API Definition.

import typing

CompanySectorEnum = typing.Union[
    typing.Literal[
        "AGRICULTURE",
        "COMMUNICATION",
        "CONSTRUCTION",
        "EDUCATION",
        "ENERGY",
        "ENTERTAINMENT",
        "FINANCIAL",
        "GAMBLING",
        "GOVERNMENT",
        "HEALTHCARE",
        "HOSPITALITY",
        "INSURANCE",
        "MANUFACTURING",
        "NGO",
        "REAL_ESTATE",
        "RETAIL",
        "TECHNOLOGY",
    ],
    typing.Any,
]
