# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SmsValidationResponseTotal(UniversalBaseModel):
    gsm_7: typing_extensions.Annotated[float, FieldMetadata(alias="gsm7")] = pydantic.Field()
    """
    Total price of this message. Calculated by multiplying the number of GSM-7 segments by the unit cost. <br>
    
    You must remove all unsupported UTF-16 characters before this message can be sent as GSM-7.
    """

    utf_16: typing_extensions.Annotated[float, FieldMetadata(alias="utf16")] = pydantic.Field()
    """
    Total price of this message. Calculated by multiplying the number of UTF-16 segments by the unit cost.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
