# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .messaging_profile_enum import MessagingProfileEnum


class PhoneNumberCampaignDetachPhoneNumbersItemCampaign(UniversalBaseModel):
    """
    Campaign that the phone is now detached from.
    """

    id: str = pydantic.Field()
    """
    Id of the campaign. For `TOLL_FREE` campaigns, it will begin with the prefix `tf_`, for example: `tf_1234567890`. For `10DLC` campaigns, it will begin with the prefix `dlc_`, for example: `dlc_1234567890`.
    """

    name: str = pydantic.Field()
    """
    Campaign's name.
    """

    type: MessagingProfileEnum

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
