# This file was auto-generated by Fern from our API Definition.

import typing

ConversationsListMessagesRequestStatus = typing.Union[
    typing.Literal["PENDING", "SENT", "SEND_FAILED", "DELIVERED", "DELIVERY_FAILED", "RECEIVED", "READ"], typing.Any
]
