# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .rich_standalone_card_options import RichStandaloneCardOptions
from .send_rich_message_options import SendRichMessageOptions


class SendRichCardsOptions(SendRichMessageOptions):
    standalone_card: typing.Optional[RichStandaloneCardOptions] = pydantic.Field(default=None)
    """
    Configure standalone card layout options for enhanced visual presentation.
    
    > **⚠️ Important Restriction**
    >
    > This option is **only valid for single card messages** with static media. Using it with multiple cards will cause the request to fail with a validation error.
    > GIFs and videos are not supported and will be rendered as vertical cards.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
