# This file was auto-generated by Fern from our API Definition.

import typing

from .rcs_validate_content_media import RcsValidateContentMedia
from .rich_cards import RichCards
from .rich_text import RichText

RcsValidateContent = typing.Union[RichText, RcsValidateContentMedia, RichCards]
