# This file was auto-generated by Fern from our API Definition.

import typing

DlcWithExtendedBrandAndStatusMnoTcrTier = typing.Union[
    typing.Literal["A", "B", "C", "D", "E", "F", "G", "N", "T", "S"], typing.Any
]
