# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .campaign_validation_response_errors_item import CampaignValidationResponseErrorsItem


class CampaignValidationResult(UniversalBaseModel):
    errors: typing.List[CampaignValidationResponseErrorsItem] = pydantic.Field()
    """
    List of validation errors.
    """

    is_valid: bool = pydantic.Field()
    """
    Whether the campaign is valid or not.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
