# This file was auto-generated by Fern from our API Definition.

import typing

VCardEmailSchemaTypeItem = typing.Union[
    typing.Literal[
        "PREF",
        "INTERNET",
        "X400",
        "AOL",
        "APPLELINK",
        "ATTMAIL",
        "CIS",
        "EWORLD",
        "IBMMAIL",
        "MCIMAIL",
        "POWERSHARE",
        "PRODIGY",
        "TLX",
    ],
    typing.Any,
]
