# This file was auto-generated by Fern from our API Definition.

import typing

PhoneFeatureEnum = typing.Union[
    typing.Literal["SMS", "MMS", "VOICE", "FAX", "EMERGENCY", "HD_VOICE", "INTERNATIONAL_SMS", "LOCAL_CALLING"],
    typing.Any,
]
