# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .validation_error_details import ValidationErrorDetails


class ValidationResults(UniversalBaseModel):
    errors: typing.List[ValidationErrorDetails] = pydantic.Field()
    """
    List of validation errors, if any.
    """

    is_valid: typing_extensions.Annotated[bool, FieldMetadata(alias="isValid")] = pydantic.Field()
    """
    Whether the brand data is valid.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
