# This file was auto-generated by Fern from our API Definition.

import typing

from .button_clicked import ButtonClicked
from .mms_content import MmsContent
from .rcs_content import RcsContent
from .sms_content import SmsContent

MessageContent = typing.Union[SmsContent, MmsContent, RcsContent, ButtonClicked]
