# This file was auto-generated by Fern from our API Definition.

import typing

DlcWithExtendedBrandAndStatusMnoBrandTier = typing.Union[
    typing.Literal["TOP", "HIGH_MID", "LOW_MID", "LOW"], typing.Any
]
