# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .toll_free_autofill_response import TollFreeAutofillResponse
    from .toll_free_campaign_help_keywords import TollFreeCampaignHelpKeywords
    from .toll_free_campaign_keywords import TollFreeCampaignKeywords
    from .toll_free_campaign_links import TollFreeCampaignLinks
    from .toll_free_campaign_opt_in import TollFreeCampaignOptIn
    from .toll_free_campaign_opt_in_keywords import TollFreeCampaignOptInKeywords
    from .toll_free_campaign_options import TollFreeCampaignOptions
    from .toll_free_campaign_use_case import TollFreeCampaignUseCase
_dynamic_imports: typing.Dict[str, str] = {
    "TollFreeAutofillResponse": ".toll_free_autofill_response",
    "TollFreeCampaignHelpKeywords": ".toll_free_campaign_help_keywords",
    "TollFreeCampaignKeywords": ".toll_free_campaign_keywords",
    "TollFreeCampaignLinks": ".toll_free_campaign_links",
    "TollFreeCampaignOptIn": ".toll_free_campaign_opt_in",
    "TollFreeCampaignOptInKeywords": ".toll_free_campaign_opt_in_keywords",
    "TollFreeCampaignOptions": ".toll_free_campaign_options",
    "TollFreeCampaignUseCase": ".toll_free_campaign_use_case",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "TollFreeAutofillResponse",
    "TollFreeCampaignHelpKeywords",
    "TollFreeCampaignKeywords",
    "TollFreeCampaignLinks",
    "TollFreeCampaignOptIn",
    "TollFreeCampaignOptInKeywords",
    "TollFreeCampaignOptions",
    "TollFreeCampaignUseCase",
]
