# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .enhanced_contact_info import EnhancedContactInfo


class RetrievePhoneNumberDetailsOptions(UniversalBaseModel):
    """
    Customize your lookup with additional options.
    """

    force: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Allows you to force a fresh lookup from primary sources instead of cached data. <br>
    
    Fresh lookups will take longer to complete than cached lookups.
    """

    risk: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include a fraud risk and security analysis.
    """

    enhanced_contact_info: typing.Optional[EnhancedContactInfo] = pydantic.Field(default=None)
    """
    Additional information to tailor lookup.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
