# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.scheduled_message import ScheduledMessage
from ....types.sent_mms_details import SentMmsDetails

MmsSendResponse = typing.Union[SentMmsDetails, ScheduledMessage]
