# This file was auto-generated by Fern from our API Definition.

import typing

PhoneNumberEnum = typing.Union[
    typing.Literal["LANDLINE", "MOBILE", "SATELLITE", "PREMIUM", "PAGING", "SPECIAL", "TOLL_FREE", "UNKNOWN"],
    typing.Any,
]
