# This file was auto-generated by Fern from our API Definition.

import typing

CompanyTypeEnum = typing.Union[
    typing.Literal["GOVERNMENT", "NON_PROFIT", "PRIVATE_PROFIT", "PUBLIC_PROFIT", "SOLE_PROPRIETOR"], typing.Any
]
