# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .link_click_event import LinkClickEvent
from .shortened_url import ShortenedUrl


class ShortenedUrlWithClickData(ShortenedUrl):
    clicks: typing.List[LinkClickEvent] = pydantic.Field()
    """
    Array of click analytics data for this URL. <br>
    
    Click data will be empty if no one has visited your link yet.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
