# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....core.serialization import FieldMetadata
from .toll_free_campaign_help_keywords import TollFreeCampaignHelpKeywords
from .toll_free_campaign_opt_in_keywords import TollFreeCampaignOptInKeywords


class TollFreeCampaignKeywords(UniversalBaseModel):
    """
    Keyword response configuration.
    """

    help: typing_extensions.Annotated[typing.Optional[TollFreeCampaignHelpKeywords], FieldMetadata(alias="HELP")] = (
        pydantic.Field(default=None)
    )
    """
    Help keyword settings.
    """

    opt_in: typing_extensions.Annotated[
        typing.Optional[TollFreeCampaignOptInKeywords], FieldMetadata(alias="OPT_IN")
    ] = pydantic.Field(default=None)
    """
    Opt-in keyword settings.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
