# This file was auto-generated by Fern from our API Definition.

import typing

TollFreeCampaignUseCaseEnum = typing.Union[
    typing.Literal[
        "APP_NOTIFICATIONS",
        "APPOINTMENTS",
        "AUCTIONS",
        "AUTO_REPAIR_SERVICES",
        "BANK_TRANSFERS",
        "BILLING",
        "BOOKING_CONFIRMATIONS",
        "BUSINESS_UPDATES",
        "CAREER_TRAINING",
        "CHATBOT",
        "CONVERSATIONAL_ALERTS",
        "COURIER_SERVICES_DELIVERIES",
        "COVID_19_ALERTS",
        "EMERGENCY_ALERTS",
        "EVENTS_PLANNING",
        "FINANCIAL_SERVICES",
        "FRAUD_ALERTS",
        "FUNDRAISING",
        "GENERAL_MARKETING",
        "GENERAL_SCHOOL_UPDATES",
        "HEALTHCARE_ALERTS",
        "HOUSING_COMMUNITY_UPDATES",
        "HR_STAFFING",
        "INSURANCE_SERVICES",
        "JOB_DISPATCH",
        "LEGAL_SERVICES",
        "MIXED",
        "MOTIVATIONAL_REMINDERS",
        "NOTARY_NOTIFICATIONS",
        "ORDER_NOTIFICATIONS",
        "POLITICAL",
        "PUBLIC_WORKS",
        "REAL_ESTATE_SERVICES",
        "RELIGIOUS_SERVICES",
        "REPAIR_DIAGNOSTICS_ALERTS",
        "REWARDS_PROGRAM",
        "SURVEYS",
        "SYSTEM_ALERTS",
        "TWO_FA",
        "VOTING_REMINDERS",
        "WAITLIST_ALERTS",
        "WEBINAR_REMINDERS",
        "WORKSHOP_ALERTS",
    ],
    typing.Any,
]
