# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .phone_number_campaign_detach_failed_item import PhoneNumberCampaignDetachFailedItem
from .phone_number_campaign_detach_phone_numbers_item import PhoneNumberCampaignDetachPhoneNumbersItem


class DetachedPhoneNumberResult(UniversalBaseModel):
    phone_numbers: typing_extensions.Annotated[
        typing.List[PhoneNumberCampaignDetachPhoneNumbersItem], FieldMetadata(alias="phoneNumbers")
    ] = pydantic.Field()
    """
    List of phone numbers.
    """

    failed: typing.List[PhoneNumberCampaignDetachFailedItem] = pydantic.Field()
    """
    List of numbers that were not failed to be detached.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
