# This file was auto-generated by Fern from our API Definition.

import typing

from .attach_webhook_by_id_params import AttachWebhookByIdParams
from .create_and_attach_webhook_by_url_params import CreateAndAttachWebhookByUrlParams

AttachWebhookParams = typing.Union[AttachWebhookByIdParams, CreateAndAttachWebhookByUrlParams]
