# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OptionalContacts(UniversalBaseModel):
    """
    Contact information for the primary brand representative.
    """

    email: typing.Optional[str] = pydantic.Field(default=None)
    """
    Email address of the contact person.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Full name of the contact person.
    """

    phone: typing.Optional[str] = pydantic.Field(default=None)
    """
    Phone number of the contact person in E.164 format.
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Job title or position oft he contact person.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
