# This file was auto-generated by Fern from our API Definition.

import typing

MessageStatusEnum = typing.Union[
    typing.Literal["QUEUED", "PENDING", "SENT", "SEND_FAILED", "DELIVERED", "DELIVERY_FAILED", "RECEIVED", "READ"],
    typing.Any,
]
