# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .phone_number_campaign_attach_phone_numbers_item_campaign import PhoneNumberCampaignAttachPhoneNumbersItemCampaign


class PhoneNumberCampaignAttachPhoneNumbersItem(UniversalBaseModel):
    phone_number: typing_extensions.Annotated[str, FieldMetadata(alias="phoneNumber")] = pydantic.Field()
    """
    Phone number (E.164 format).
    """

    campaign: PhoneNumberCampaignAttachPhoneNumbersItemCampaign = pydantic.Field()
    """
    Campaign that the phone is now attached to.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
