# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SmsValidationResponseSegmentsUtf16(UniversalBaseModel):
    """
    Segmentation details when your message is encoded with UTF-16.
    """

    total_bytes: typing_extensions.Annotated[int, FieldMetadata(alias="totalBytes")] = pydantic.Field()
    """
    Total number of bytes used by the UTF-16 segments.
    """

    value: typing.List[str] = pydantic.Field()
    """
    Message broken down into segments using UTF-16 encoding.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
