# This file was auto-generated by Fern from our API Definition.

import typing

from .rcs_cards_content import RcsCardsContent
from .rcs_media_content import RcsMediaContent
from .rich_text import RichText

RcsContent = typing.Union[RichText, RcsMediaContent, RcsCardsContent]
