# This file was auto-generated by Fern from our API Definition.

import typing

DlcAssignmentStatusEnum = typing.Union[
    typing.Literal[
        "ASSIGNED", "FAILED_ASSIGNMENT", "FAILED_UNASSIGNMENT", "PENDING_ASSIGNMENT", "PENDING_UNASSIGNMENT"
    ],
    typing.Any,
]
