# This file was auto-generated by Fern from our API Definition.

import typing

BrandStatusEnum = typing.Union[
    typing.Literal["PENDING", "UNVERIFIED", "VERIFIED", "VETTED", "FAILED", "INCOMPLETE"], typing.Any
]
