# This file was auto-generated by Fern from our API Definition.

import typing

SubUseCaseEnum = typing.Union[
    typing.Literal[
        "ACCOUNT_NOTIFICATION",
        "CUSTOMER_CARE",
        "DELIVERY_NOTIFICATION",
        "FRAUD_ALERT",
        "HIGHER_EDUCATION",
        "MARKETING",
        "POLLING_VOTING",
        "PUBLIC_SERVICE_ANNOUNCEMENT",
        "SECURITY_ALERT",
        "TWO_FA",
    ],
    typing.Any,
]
