# This file was auto-generated by Fern from our API Definition.

import typing

CompanyEntityTypeEnum = typing.Union[
    typing.Literal["LLC", "SOLE_PROPRIETORSHIP", "PARTNERSHIP", "CORP", "S_CORP"], typing.Any
]
