# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .rcs_agent import RcsAgent
    from .rcs_agent_email import RcsAgentEmail
    from .rcs_agent_phone import RcsAgentPhone
    from .rcs_agent_website import RcsAgentWebsite
    from .rcs_autofill_response import RcsAutofillResponse
    from .rcs_campaign_help_keywords import RcsCampaignHelpKeywords
    from .rcs_campaign_keywords import RcsCampaignKeywords
    from .rcs_campaign_opt_in_keywords import RcsCampaignOptInKeywords
    from .rcs_campaign_opt_out_keywords import RcsCampaignOptOutKeywords
    from .rcs_campaign_traffic import RcsCampaignTraffic
    from .rcs_links import RcsLinks
    from .rcs_use_case import RcsUseCase
_dynamic_imports: typing.Dict[str, str] = {
    "RcsAgent": ".rcs_agent",
    "RcsAgentEmail": ".rcs_agent_email",
    "RcsAgentPhone": ".rcs_agent_phone",
    "RcsAgentWebsite": ".rcs_agent_website",
    "RcsAutofillResponse": ".rcs_autofill_response",
    "RcsCampaignHelpKeywords": ".rcs_campaign_help_keywords",
    "RcsCampaignKeywords": ".rcs_campaign_keywords",
    "RcsCampaignOptInKeywords": ".rcs_campaign_opt_in_keywords",
    "RcsCampaignOptOutKeywords": ".rcs_campaign_opt_out_keywords",
    "RcsCampaignTraffic": ".rcs_campaign_traffic",
    "RcsLinks": ".rcs_links",
    "RcsUseCase": ".rcs_use_case",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "RcsAgent",
    "RcsAgentEmail",
    "RcsAgentPhone",
    "RcsAgentWebsite",
    "RcsAutofillResponse",
    "RcsCampaignHelpKeywords",
    "RcsCampaignKeywords",
    "RcsCampaignOptInKeywords",
    "RcsCampaignOptOutKeywords",
    "RcsCampaignTraffic",
    "RcsLinks",
    "RcsUseCase",
]
