# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class RcsValidationResult(UniversalBaseModel):
    total: float = pydantic.Field()
    """
    Total price of this message. Calculated by multiplying the number of messages by the unit cost.
    """

    unit: float = pydantic.Field()
    """
    Cost per message.
    """

    segments: int = pydantic.Field()
    """
    Total number of segments used across the message.
    """

    unsupported_files: typing_extensions.Annotated[typing.List[str], FieldMetadata(alias="unsupportedFiles")] = (
        pydantic.Field()
    )
    """
    List of unsupported media file names or URLs.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
