# This file was auto-generated by Fern from our API Definition.

import typing

DetailedPhoneNumberEnum = typing.Union[
    typing.Literal[
        "FIXED_LINE",
        "INVALID",
        "MOBILE",
        "OTHER",
        "PAGER",
        "PAYPHONE",
        "PERSONAL",
        "PREPAID",
        "RESTRICTED_PREMIUM",
        "TOLL_FREE",
        "VOICEMAIL",
        "VOIP",
    ],
    typing.Any,
]
