# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.scheduled_message import ScheduledMessage
from ....types.sent_rich_message import SentRichMessage

SendRichMessageResponse = typing.Union[SentRichMessage, ScheduledMessage]
