# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class AudienceCountOnly(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Audience public ID. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.
    """

    name: str = pydantic.Field()
    """
    Audience name.
    """

    description: str = pydantic.Field()
    """
    Audience description.
    """

    contact_count: typing_extensions.Annotated[int, FieldMetadata(alias="contactCount")] = pydantic.Field()
    """
    Total number of contacts in audience.
    
    Use the [Get Audience](/api-reference/audiences/get) endpoint with the pagination parameters to get the audience with its contacts.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
