# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class AdvancedPhoneInformationLocationCountry(UniversalBaseModel):
    """
    Complete country identification and metadata.
    """

    name: str = pydantic.Field()
    """
    Name of the country.
    """

    code: str = pydantic.Field()
    """
    Two-letter country code where the number is registered.
    """

    code_3: typing_extensions.Annotated[str, FieldMetadata(alias="code3")] = pydantic.Field()
    """
    Three-letter country code where the number is registered.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
