# This file was auto-generated by Fern from our API Definition.

import typing

from .conversation_by_id_params import ConversationByIdParams
from .conversation_by_participants_params import ConversationByParticipantsParams

GetConversationParams = typing.Union[ConversationByIdParams, ConversationByParticipantsParams]
