# This file was auto-generated by Fern from our API Definition.

import typing

VCardAddressSchemaTypeItem = typing.Union[
    typing.Literal["DOM", "INTL", "POSTAL", "PARCEL", "HOME", "WORK", "PREF"], typing.Any
]
