# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.audience_count_only import AudienceCountOnly
from ...types.audience_with_pagination import AudienceWithPagination

AudiencesGetResponse = typing.Union[AudienceWithPagination, AudienceCountOnly]
