# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dlc_campaign_use_case_enum import DlcCampaignUseCaseEnum
from .sub_use_case_enum import SubUseCaseEnum


class AutofillDlcResponseUseCase(UniversalBaseModel):
    """
    Use case for the campaign.
    """

    sub: typing.Optional[typing.List[SubUseCaseEnum]] = pydantic.Field(default=None)
    """
    Sub-use case categories.
    """

    value: typing.Optional[DlcCampaignUseCaseEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
