# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....core.serialization import FieldMetadata


class RcsCampaignTraffic(UniversalBaseModel):
    monthly_website: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="monthlyWebsite")] = (
        pydantic.Field(default=None)
    )
    """
    Estimated monthly website visitors.
    """

    monthly_rcs_estimate: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="monthlyRcsEstimate")
    ] = pydantic.Field(default=None)
    """
    Estimated monthly RCS messages sent.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
