# This file was auto-generated by Fern from our API Definition.

import typing

RcsCampaignUseCaseEnum = typing.Union[
    typing.Literal[
        "ENTERTAINMENT",
        "SHOPPING_AND_RETAIL",
        "GAMES",
        "NEWS",
        "HEALTH",
        "UTILITIES",
        "FINANCE",
        "SPORTS",
        "SOCIAL",
        "FOOD_AND_BEVERAGE",
        "UNCATEGORIZED",
        "TRAVEL",
        "PRODUCTIVITY",
        "OTHER",
    ],
    typing.Any,
]
