# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ReactMessageOptions(UniversalBaseModel):
    force: typing.Optional[bool] = pydantic.Field(default=None)
    """
    By default, only messages sent with the `options.tracking` field can be precisely reacted to. <br>
    
    Set `options.force` to true to bypass this restriction (may react to a different message). <br>
    
    For MMS and RCS, only messages containing text can be tracked. Otherwise, `options.force` is ignored.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
