# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .campaign_enum import CampaignEnum


class CampaignQuery(UniversalBaseModel):
    """
    Information about the campaign associated with a conversation
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the campaign. This identifier is a string that begins with the prefix: 
    - TOLL_FREE: `tf_` (e.g., `tf_1234567890`)
    - 10DLC: `dlc_` (e.g., `dlc_1234567890`)
    - RCS: `rcs_` (e.g., `rcs_1234567890`)
    """

    type: CampaignEnum

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
