# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .advanced_phone_information import AdvancedPhoneInformation
    from .advanced_phone_information_carrier import AdvancedPhoneInformationCarrier
    from .advanced_phone_information_contact import AdvancedPhoneInformationContact
    from .advanced_phone_information_location import AdvancedPhoneInformationLocation
    from .advanced_phone_information_location_coordinates import AdvancedPhoneInformationLocationCoordinates
    from .advanced_phone_information_location_country import AdvancedPhoneInformationLocationCountry
    from .advanced_phone_information_type import AdvancedPhoneInformationType
    from .advanced_phone_information_type_recommendation import AdvancedPhoneInformationTypeRecommendation
    from .agent import Agent
    from .attach_webhook_by_id_params import AttachWebhookByIdParams
    from .attach_webhook_params import AttachWebhookParams
    from .attach_webhook_response_webhook import AttachWebhookResponseWebhook
    from .attached_phone_number_result import AttachedPhoneNumberResult
    from .audience_count_only import AudienceCountOnly
    from .audience_with_pagination import AudienceWithPagination
    from .autofill_campaign_params import AutofillCampaignParams
    from .autofill_dlc_campaign_response import AutofillDlcCampaignResponse
    from .autofill_dlc_response_keywords import AutofillDlcResponseKeywords
    from .autofill_dlc_response_keywords_help import AutofillDlcResponseKeywordsHelp
    from .autofill_dlc_response_keywords_opt_in import AutofillDlcResponseKeywordsOptIn
    from .autofill_dlc_response_keywords_opt_out import AutofillDlcResponseKeywordsOptOut
    from .autofill_dlc_response_links import AutofillDlcResponseLinks
    from .autofill_dlc_response_options import AutofillDlcResponseOptions
    from .autofill_dlc_response_use_case import AutofillDlcResponseUseCase
    from .bad_request_error_body import BadRequestErrorBody
    from .base_rich_message import BaseRichMessage
    from .basic_phone_information import BasicPhoneInformation
    from .basic_phone_information_contact import BasicPhoneInformationContact
    from .basic_phone_information_location import BasicPhoneInformationLocation
    from .basic_phone_information_location_country import BasicPhoneInformationLocationCountry
    from .blast_details import BlastDetails
    from .brand_status import BrandStatus
    from .brand_status_enum import BrandStatusEnum
    from .button_clicked import ButtonClicked
    from .button_clicked_data import ButtonClickedData
    from .button_clicked_data_button import ButtonClickedDataButton
    from .button_clicked_data_button_raw import ButtonClickedDataButtonRaw
    from .button_clicked_data_button_type import ButtonClickedDataButtonType
    from .buy_response_capabilities import BuyResponseCapabilities
    from .campaign_enum import CampaignEnum
    from .campaign_query import CampaignQuery
    from .campaign_submission_result import CampaignSubmissionResult
    from .campaign_validation_response_errors_item import CampaignValidationResponseErrorsItem
    from .campaign_validation_result import CampaignValidationResult
    from .company_entity_type_enum import CompanyEntityTypeEnum
    from .company_sector_enum import CompanySectorEnum
    from .company_type_enum import CompanyTypeEnum
    from .configured_webhook import ConfiguredWebhook
    from .contact import Contact
    from .contact_id import ContactId
    from .conversation import Conversation
    from .conversation_by_id_params import ConversationByIdParams
    from .conversation_by_participants_params import ConversationByParticipantsParams
    from .conversation_contact import ConversationContact
    from .conversation_list import ConversationList
    from .conversation_sender import ConversationSender
    from .create_and_attach_webhook_by_url_params import CreateAndAttachWebhookByUrlParams
    from .create_url_options import CreateUrlOptions
    from .delete_audience_response import DeleteAudienceResponse
    from .detached_phone_number_result import DetachedPhoneNumberResult
    from .detached_webhook_info import DetachedWebhookInfo
    from .detailed_phone_number_enum import DetailedPhoneNumberEnum
    from .dlc_assignment_status_enum import DlcAssignmentStatusEnum
    from .dlc_campaign_status import DlcCampaignStatus
    from .dlc_campaign_use_case_enum import DlcCampaignUseCaseEnum
    from .dlc_campaign_with_extended_brand_and_status import DlcCampaignWithExtendedBrandAndStatus
    from .dlc_with_extended_brand_and_status_keywords import DlcWithExtendedBrandAndStatusKeywords
    from .dlc_with_extended_brand_and_status_keywords_help import DlcWithExtendedBrandAndStatusKeywordsHelp
    from .dlc_with_extended_brand_and_status_keywords_opt_in import DlcWithExtendedBrandAndStatusKeywordsOptIn
    from .dlc_with_extended_brand_and_status_keywords_opt_out import DlcWithExtendedBrandAndStatusKeywordsOptOut
    from .dlc_with_extended_brand_and_status_links import DlcWithExtendedBrandAndStatusLinks
    from .dlc_with_extended_brand_and_status_mno_brand_tier import DlcWithExtendedBrandAndStatusMnoBrandTier
    from .dlc_with_extended_brand_and_status_mno_tcr_tier import DlcWithExtendedBrandAndStatusMnoTcrTier
    from .dlc_with_extended_brand_and_status_options import DlcWithExtendedBrandAndStatusOptions
    from .dlc_with_extended_brand_and_status_use_case import DlcWithExtendedBrandAndStatusUseCase
    from .enhanced_contact import EnhancedContact
    from .enhanced_contact_item import EnhancedContactItem
    from .error import Error
    from .extended_brand import ExtendedBrand
    from .extended_brand_with_vetting import ExtendedBrandWithVetting
    from .extended_rcs_campaign import ExtendedRcsCampaign
    from .get_conversation_params import GetConversationParams
    from .get_dlc_campaign_status_response_updates import GetDlcCampaignStatusResponseUpdates
    from .get_toll_free_campaign_status_response_updates import GetTollFreeCampaignStatusResponseUpdates
    from .link_click_event import LinkClickEvent
    from .location_share_action import LocationShareAction
    from .location_share_action_data import LocationShareActionData
    from .message import Message
    from .message_content import MessageContent
    from .message_event import MessageEvent
    from .message_event_content import MessageEventContent
    from .message_event_conversation import MessageEventConversation
    from .message_event_direction import MessageEventDirection
    from .message_event_mms_content import MessageEventMmsContent
    from .message_event_rcs_button_data import MessageEventRcsButtonData
    from .message_event_rcs_cards_content import MessageEventRcsCardsContent
    from .message_event_rcs_cards_content_cards_item import MessageEventRcsCardsContentCardsItem
    from .message_event_rcs_location_data import MessageEventRcsLocationData
    from .message_event_rcs_media_content import MessageEventRcsMediaContent
    from .message_event_rcs_text_content import MessageEventRcsTextContent
    from .message_event_sms_content import MessageEventSmsContent
    from .message_list import MessageList
    from .message_method_enum import MessageMethodEnum
    from .message_protocol_enum import MessageProtocolEnum
    from .message_schedule import MessageSchedule
    from .message_status_enum import MessageStatusEnum
    from .message_volume_enum import MessageVolumeEnum
    from .message_with_reaction import MessageWithReaction
    from .message_with_reaction_direction import MessageWithReactionDirection
    from .messaging_profile_enum import MessagingProfileEnum
    from .mms_content import MmsContent
    from .mms_validation_response_segments import MmsValidationResponseSegments
    from .mms_validation_response_segments_value_item import MmsValidationResponseSegmentsValueItem
    from .mms_validation_result import MmsValidationResult
    from .not_found_error_body import NotFoundErrorBody
    from .number_format import NumberFormat
    from .opt_in_method_enum import OptInMethodEnum
    from .optional_brand_info import OptionalBrandInfo
    from .optional_contact import OptionalContact
    from .optional_contacts import OptionalContacts
    from .pagination import Pagination
    from .phone import Phone
    from .phone_capabilities import PhoneCapabilities
    from .phone_enum import PhoneEnum
    from .phone_feature_enum import PhoneFeatureEnum
    from .phone_number_campaign_attach_failed_item import PhoneNumberCampaignAttachFailedItem
    from .phone_number_campaign_attach_phone_numbers_item import PhoneNumberCampaignAttachPhoneNumbersItem
    from .phone_number_campaign_attach_phone_numbers_item_campaign import (
        PhoneNumberCampaignAttachPhoneNumbersItemCampaign,
    )
    from .phone_number_campaign_detach_failed_item import PhoneNumberCampaignDetachFailedItem
    from .phone_number_campaign_detach_phone_numbers_item import PhoneNumberCampaignDetachPhoneNumbersItem
    from .phone_number_campaign_detach_phone_numbers_item_campaign import (
        PhoneNumberCampaignDetachPhoneNumbersItemCampaign,
    )
    from .phone_number_cost import PhoneNumberCost
    from .phone_number_details import PhoneNumberDetails
    from .phone_number_enum import PhoneNumberEnum
    from .phone_number_region import PhoneNumberRegion
    from .phone_number_status import PhoneNumberStatus
    from .phone_number_status_enum import PhoneNumberStatusEnum
    from .pinnacle_file_upload_metadata import PinnacleFileUploadMetadata
    from .pinnacle_url_config import PinnacleUrlConfig
    from .profile_status_enum import ProfileStatusEnum
    from .purchased_number import PurchasedNumber
    from .rcs_button_call import RcsButtonCall
    from .rcs_button_open_url import RcsButtonOpenUrl
    from .rcs_button_open_url_webview_mode import RcsButtonOpenUrlWebviewMode
    from .rcs_button_request_user_location import RcsButtonRequestUserLocation
    from .rcs_button_schedule_event import RcsButtonScheduleEvent
    from .rcs_button_send_location import RcsButtonSendLocation
    from .rcs_button_send_location_lat_long import RcsButtonSendLocationLatLong
    from .rcs_button_trigger import RcsButtonTrigger
    from .rcs_campaign import RcsCampaign
    from .rcs_campaign_schema_agent import RcsCampaignSchemaAgent
    from .rcs_campaign_schema_agent_emails_item import RcsCampaignSchemaAgentEmailsItem
    from .rcs_campaign_schema_agent_phones_item import RcsCampaignSchemaAgentPhonesItem
    from .rcs_campaign_schema_agent_websites_item import RcsCampaignSchemaAgentWebsitesItem
    from .rcs_campaign_schema_extra_agent import RcsCampaignSchemaExtraAgent
    from .rcs_campaign_schema_extra_agent_emails_item import RcsCampaignSchemaExtraAgentEmailsItem
    from .rcs_campaign_schema_extra_agent_phones_item import RcsCampaignSchemaExtraAgentPhonesItem
    from .rcs_campaign_schema_extra_agent_websites_item import RcsCampaignSchemaExtraAgentWebsitesItem
    from .rcs_campaign_schema_extra_keywords import RcsCampaignSchemaExtraKeywords
    from .rcs_campaign_schema_extra_keywords_help import RcsCampaignSchemaExtraKeywordsHelp
    from .rcs_campaign_schema_extra_keywords_opt_in import RcsCampaignSchemaExtraKeywordsOptIn
    from .rcs_campaign_schema_extra_keywords_opt_out import RcsCampaignSchemaExtraKeywordsOptOut
    from .rcs_campaign_schema_extra_links import RcsCampaignSchemaExtraLinks
    from .rcs_campaign_schema_extra_traffic import RcsCampaignSchemaExtraTraffic
    from .rcs_campaign_schema_extra_use_case import RcsCampaignSchemaExtraUseCase
    from .rcs_campaign_schema_keywords import RcsCampaignSchemaKeywords
    from .rcs_campaign_schema_keywords_help import RcsCampaignSchemaKeywordsHelp
    from .rcs_campaign_schema_keywords_opt_in import RcsCampaignSchemaKeywordsOptIn
    from .rcs_campaign_schema_keywords_opt_out import RcsCampaignSchemaKeywordsOptOut
    from .rcs_campaign_schema_links import RcsCampaignSchemaLinks
    from .rcs_campaign_schema_traffic import RcsCampaignSchemaTraffic
    from .rcs_campaign_schema_use_case import RcsCampaignSchemaUseCase
    from .rcs_campaign_status import RcsCampaignStatus
    from .rcs_campaign_use_case_enum import RcsCampaignUseCaseEnum
    from .rcs_capabilities_result import RcsCapabilitiesResult
    from .rcs_capability import RcsCapability
    from .rcs_capability_actions import RcsCapabilityActions
    from .rcs_capability_cards import RcsCapabilityCards
    from .rcs_cards_content import RcsCardsContent
    from .rcs_cards_content_cards_item import RcsCardsContentCardsItem
    from .rcs_content import RcsContent
    from .rcs_link_result import RcsLinkResult
    from .rcs_media_content import RcsMediaContent
    from .rcs_media_details_content import RcsMediaDetailsContent
    from .rcs_messaging_type_enum import RcsMessagingTypeEnum
    from .rcs_validate_content import RcsValidateContent
    from .rcs_validate_content_media import RcsValidateContentMedia
    from .rcs_validation_result import RcsValidationResult
    from .rcs_whitelist_response import RcsWhitelistResponse
    from .reaction_result import ReactionResult
    from .refreshed_file import RefreshedFile
    from .rich_button import (
        RichButton,
        RichButton_Call,
        RichButton_OpenUrl,
        RichButton_RequestUserLocation,
        RichButton_ScheduleEvent,
        RichButton_SendLocation,
        RichButton_Trigger,
    )
    from .rich_card import RichCard
    from .rich_cards import RichCards
    from .rich_cards_message import RichCardsMessage
    from .rich_media_message import RichMediaMessage
    from .rich_message import RichMessage
    from .rich_standalone_card_options import RichStandaloneCardOptions
    from .rich_text import RichText
    from .rich_text_message import RichTextMessage
    from .schedule_cancel_result import ScheduleCancelResult
    from .scheduled_blast_details import ScheduledBlastDetails
    from .scheduled_blast_response_config import ScheduledBlastResponseConfig
    from .scheduled_message import ScheduledMessage
    from .scheduled_send_response_config import ScheduledSendResponseConfig
    from .send_rcs_card_options_standalone_card_image_alignment import SendRcsCardOptionsStandaloneCardImageAlignment
    from .send_rcs_card_options_standalone_card_orientation import SendRcsCardOptionsStandaloneCardOrientation
    from .send_rich_cards_options import SendRichCardsOptions
    from .send_rich_message_options import SendRichMessageOptions
    from .send_sms_response_segments import SendSmsResponseSegments
    from .send_sms_response_segments_encoding import SendSmsResponseSegmentsEncoding
    from .send_typing_indicator_response import SendTypingIndicatorResponse
    from .sender import Sender
    from .sent_mms_details import SentMmsDetails
    from .sent_rich_message import SentRichMessage
    from .sent_sms_details import SentSmsDetails
    from .shortened_url import ShortenedUrl
    from .shortened_url_with_click_data import ShortenedUrlWithClickData
    from .sms_content import SmsContent
    from .sms_validation_response_segments import SmsValidationResponseSegments
    from .sms_validation_response_segments_gsm_7 import SmsValidationResponseSegmentsGsm7
    from .sms_validation_response_segments_utf_16 import SmsValidationResponseSegmentsUtf16
    from .sms_validation_response_total import SmsValidationResponseTotal
    from .sms_validation_result import SmsValidationResult
    from .sub_use_case_enum import SubUseCaseEnum
    from .submission_results import SubmissionResults
    from .successful_conversation_update import SuccessfulConversationUpdate
    from .toll_free_campaign import TollFreeCampaign
    from .toll_free_campaign_schema_keywords import TollFreeCampaignSchemaKeywords
    from .toll_free_campaign_schema_keywords_help import TollFreeCampaignSchemaKeywordsHelp
    from .toll_free_campaign_schema_keywords_opt_in import TollFreeCampaignSchemaKeywordsOptIn
    from .toll_free_campaign_schema_links import TollFreeCampaignSchemaLinks
    from .toll_free_campaign_schema_opt_in import TollFreeCampaignSchemaOptIn
    from .toll_free_campaign_schema_options import TollFreeCampaignSchemaOptions
    from .toll_free_campaign_schema_use_case import TollFreeCampaignSchemaUseCase
    from .toll_free_campaign_status import TollFreeCampaignStatus
    from .toll_free_campaign_use_case_enum import TollFreeCampaignUseCaseEnum
    from .toll_free_campaign_with_extended_brand_and_status import TollFreeCampaignWithExtendedBrandAndStatus
    from .toll_free_status_enum import TollFreeStatusEnum
    from .toll_free_with_extended_brand_and_status_keywords import TollFreeWithExtendedBrandAndStatusKeywords
    from .toll_free_with_extended_brand_and_status_keywords_help import TollFreeWithExtendedBrandAndStatusKeywordsHelp
    from .toll_free_with_extended_brand_and_status_keywords_opt_in import (
        TollFreeWithExtendedBrandAndStatusKeywordsOptIn,
    )
    from .toll_free_with_extended_brand_and_status_links import TollFreeWithExtendedBrandAndStatusLinks
    from .toll_free_with_extended_brand_and_status_opt_in import TollFreeWithExtendedBrandAndStatusOptIn
    from .toll_free_with_extended_brand_and_status_options import TollFreeWithExtendedBrandAndStatusOptions
    from .toll_free_with_extended_brand_and_status_use_case import TollFreeWithExtendedBrandAndStatusUseCase
    from .tracking import Tracking
    from .updated_contact_id import UpdatedContactId
    from .upload_results import UploadResults
    from .user_event import UserEvent
    from .user_event_conversation import UserEventConversation
    from .v_card_address_schema_type_item import VCardAddressSchemaTypeItem
    from .v_card_data import VCardData
    from .v_card_data_file import VCardDataFile
    from .v_card_data_file_metadata import VCardDataFileMetadata
    from .v_card_email_schema_type_item import VCardEmailSchemaTypeItem
    from .v_card_geo import VCardGeo
    from .v_card_name import VCardName
    from .v_card_organization import VCardOrganization
    from .v_card_phone_schema_type_item import VCardPhoneSchemaTypeItem
    from .validate_campaign_params import ValidateCampaignParams
    from .validation_error_details import ValidationErrorDetails
    from .validation_results import ValidationResults
    from .vcard import Vcard
    from .vcard_address import VcardAddress
    from .vcard_content import VcardContent
    from .vcard_email import VcardEmail
    from .vcard_phone import VcardPhone
    from .vcard_resource import VcardResource
    from .vetting_feedback import VettingFeedback
    from .vetting_history import VettingHistory
    from .vetting_history_vetting_status import VettingHistoryVettingStatus
    from .vetting_results import VettingResults
    from .webhook_event_enum import WebhookEventEnum
    from .webhook_result import WebhookResult
    from .webhooks import Webhooks
    from .zod_error import ZodError
_dynamic_imports: typing.Dict[str, str] = {
    "AdvancedPhoneInformation": ".advanced_phone_information",
    "AdvancedPhoneInformationCarrier": ".advanced_phone_information_carrier",
    "AdvancedPhoneInformationContact": ".advanced_phone_information_contact",
    "AdvancedPhoneInformationLocation": ".advanced_phone_information_location",
    "AdvancedPhoneInformationLocationCoordinates": ".advanced_phone_information_location_coordinates",
    "AdvancedPhoneInformationLocationCountry": ".advanced_phone_information_location_country",
    "AdvancedPhoneInformationType": ".advanced_phone_information_type",
    "AdvancedPhoneInformationTypeRecommendation": ".advanced_phone_information_type_recommendation",
    "Agent": ".agent",
    "AttachWebhookByIdParams": ".attach_webhook_by_id_params",
    "AttachWebhookParams": ".attach_webhook_params",
    "AttachWebhookResponseWebhook": ".attach_webhook_response_webhook",
    "AttachedPhoneNumberResult": ".attached_phone_number_result",
    "AudienceCountOnly": ".audience_count_only",
    "AudienceWithPagination": ".audience_with_pagination",
    "AutofillCampaignParams": ".autofill_campaign_params",
    "AutofillDlcCampaignResponse": ".autofill_dlc_campaign_response",
    "AutofillDlcResponseKeywords": ".autofill_dlc_response_keywords",
    "AutofillDlcResponseKeywordsHelp": ".autofill_dlc_response_keywords_help",
    "AutofillDlcResponseKeywordsOptIn": ".autofill_dlc_response_keywords_opt_in",
    "AutofillDlcResponseKeywordsOptOut": ".autofill_dlc_response_keywords_opt_out",
    "AutofillDlcResponseLinks": ".autofill_dlc_response_links",
    "AutofillDlcResponseOptions": ".autofill_dlc_response_options",
    "AutofillDlcResponseUseCase": ".autofill_dlc_response_use_case",
    "BadRequestErrorBody": ".bad_request_error_body",
    "BaseRichMessage": ".base_rich_message",
    "BasicPhoneInformation": ".basic_phone_information",
    "BasicPhoneInformationContact": ".basic_phone_information_contact",
    "BasicPhoneInformationLocation": ".basic_phone_information_location",
    "BasicPhoneInformationLocationCountry": ".basic_phone_information_location_country",
    "BlastDetails": ".blast_details",
    "BrandStatus": ".brand_status",
    "BrandStatusEnum": ".brand_status_enum",
    "ButtonClicked": ".button_clicked",
    "ButtonClickedData": ".button_clicked_data",
    "ButtonClickedDataButton": ".button_clicked_data_button",
    "ButtonClickedDataButtonRaw": ".button_clicked_data_button_raw",
    "ButtonClickedDataButtonType": ".button_clicked_data_button_type",
    "BuyResponseCapabilities": ".buy_response_capabilities",
    "CampaignEnum": ".campaign_enum",
    "CampaignQuery": ".campaign_query",
    "CampaignSubmissionResult": ".campaign_submission_result",
    "CampaignValidationResponseErrorsItem": ".campaign_validation_response_errors_item",
    "CampaignValidationResult": ".campaign_validation_result",
    "CompanyEntityTypeEnum": ".company_entity_type_enum",
    "CompanySectorEnum": ".company_sector_enum",
    "CompanyTypeEnum": ".company_type_enum",
    "ConfiguredWebhook": ".configured_webhook",
    "Contact": ".contact",
    "ContactId": ".contact_id",
    "Conversation": ".conversation",
    "ConversationByIdParams": ".conversation_by_id_params",
    "ConversationByParticipantsParams": ".conversation_by_participants_params",
    "ConversationContact": ".conversation_contact",
    "ConversationList": ".conversation_list",
    "ConversationSender": ".conversation_sender",
    "CreateAndAttachWebhookByUrlParams": ".create_and_attach_webhook_by_url_params",
    "CreateUrlOptions": ".create_url_options",
    "DeleteAudienceResponse": ".delete_audience_response",
    "DetachedPhoneNumberResult": ".detached_phone_number_result",
    "DetachedWebhookInfo": ".detached_webhook_info",
    "DetailedPhoneNumberEnum": ".detailed_phone_number_enum",
    "DlcAssignmentStatusEnum": ".dlc_assignment_status_enum",
    "DlcCampaignStatus": ".dlc_campaign_status",
    "DlcCampaignUseCaseEnum": ".dlc_campaign_use_case_enum",
    "DlcCampaignWithExtendedBrandAndStatus": ".dlc_campaign_with_extended_brand_and_status",
    "DlcWithExtendedBrandAndStatusKeywords": ".dlc_with_extended_brand_and_status_keywords",
    "DlcWithExtendedBrandAndStatusKeywordsHelp": ".dlc_with_extended_brand_and_status_keywords_help",
    "DlcWithExtendedBrandAndStatusKeywordsOptIn": ".dlc_with_extended_brand_and_status_keywords_opt_in",
    "DlcWithExtendedBrandAndStatusKeywordsOptOut": ".dlc_with_extended_brand_and_status_keywords_opt_out",
    "DlcWithExtendedBrandAndStatusLinks": ".dlc_with_extended_brand_and_status_links",
    "DlcWithExtendedBrandAndStatusMnoBrandTier": ".dlc_with_extended_brand_and_status_mno_brand_tier",
    "DlcWithExtendedBrandAndStatusMnoTcrTier": ".dlc_with_extended_brand_and_status_mno_tcr_tier",
    "DlcWithExtendedBrandAndStatusOptions": ".dlc_with_extended_brand_and_status_options",
    "DlcWithExtendedBrandAndStatusUseCase": ".dlc_with_extended_brand_and_status_use_case",
    "EnhancedContact": ".enhanced_contact",
    "EnhancedContactItem": ".enhanced_contact_item",
    "Error": ".error",
    "ExtendedBrand": ".extended_brand",
    "ExtendedBrandWithVetting": ".extended_brand_with_vetting",
    "ExtendedRcsCampaign": ".extended_rcs_campaign",
    "GetConversationParams": ".get_conversation_params",
    "GetDlcCampaignStatusResponseUpdates": ".get_dlc_campaign_status_response_updates",
    "GetTollFreeCampaignStatusResponseUpdates": ".get_toll_free_campaign_status_response_updates",
    "LinkClickEvent": ".link_click_event",
    "LocationShareAction": ".location_share_action",
    "LocationShareActionData": ".location_share_action_data",
    "Message": ".message",
    "MessageContent": ".message_content",
    "MessageEvent": ".message_event",
    "MessageEventContent": ".message_event_content",
    "MessageEventConversation": ".message_event_conversation",
    "MessageEventDirection": ".message_event_direction",
    "MessageEventMmsContent": ".message_event_mms_content",
    "MessageEventRcsButtonData": ".message_event_rcs_button_data",
    "MessageEventRcsCardsContent": ".message_event_rcs_cards_content",
    "MessageEventRcsCardsContentCardsItem": ".message_event_rcs_cards_content_cards_item",
    "MessageEventRcsLocationData": ".message_event_rcs_location_data",
    "MessageEventRcsMediaContent": ".message_event_rcs_media_content",
    "MessageEventRcsTextContent": ".message_event_rcs_text_content",
    "MessageEventSmsContent": ".message_event_sms_content",
    "MessageList": ".message_list",
    "MessageMethodEnum": ".message_method_enum",
    "MessageProtocolEnum": ".message_protocol_enum",
    "MessageSchedule": ".message_schedule",
    "MessageStatusEnum": ".message_status_enum",
    "MessageVolumeEnum": ".message_volume_enum",
    "MessageWithReaction": ".message_with_reaction",
    "MessageWithReactionDirection": ".message_with_reaction_direction",
    "MessagingProfileEnum": ".messaging_profile_enum",
    "MmsContent": ".mms_content",
    "MmsValidationResponseSegments": ".mms_validation_response_segments",
    "MmsValidationResponseSegmentsValueItem": ".mms_validation_response_segments_value_item",
    "MmsValidationResult": ".mms_validation_result",
    "NotFoundErrorBody": ".not_found_error_body",
    "NumberFormat": ".number_format",
    "OptInMethodEnum": ".opt_in_method_enum",
    "OptionalBrandInfo": ".optional_brand_info",
    "OptionalContact": ".optional_contact",
    "OptionalContacts": ".optional_contacts",
    "Pagination": ".pagination",
    "Phone": ".phone",
    "PhoneCapabilities": ".phone_capabilities",
    "PhoneEnum": ".phone_enum",
    "PhoneFeatureEnum": ".phone_feature_enum",
    "PhoneNumberCampaignAttachFailedItem": ".phone_number_campaign_attach_failed_item",
    "PhoneNumberCampaignAttachPhoneNumbersItem": ".phone_number_campaign_attach_phone_numbers_item",
    "PhoneNumberCampaignAttachPhoneNumbersItemCampaign": ".phone_number_campaign_attach_phone_numbers_item_campaign",
    "PhoneNumberCampaignDetachFailedItem": ".phone_number_campaign_detach_failed_item",
    "PhoneNumberCampaignDetachPhoneNumbersItem": ".phone_number_campaign_detach_phone_numbers_item",
    "PhoneNumberCampaignDetachPhoneNumbersItemCampaign": ".phone_number_campaign_detach_phone_numbers_item_campaign",
    "PhoneNumberCost": ".phone_number_cost",
    "PhoneNumberDetails": ".phone_number_details",
    "PhoneNumberEnum": ".phone_number_enum",
    "PhoneNumberRegion": ".phone_number_region",
    "PhoneNumberStatus": ".phone_number_status",
    "PhoneNumberStatusEnum": ".phone_number_status_enum",
    "PinnacleFileUploadMetadata": ".pinnacle_file_upload_metadata",
    "PinnacleUrlConfig": ".pinnacle_url_config",
    "ProfileStatusEnum": ".profile_status_enum",
    "PurchasedNumber": ".purchased_number",
    "RcsButtonCall": ".rcs_button_call",
    "RcsButtonOpenUrl": ".rcs_button_open_url",
    "RcsButtonOpenUrlWebviewMode": ".rcs_button_open_url_webview_mode",
    "RcsButtonRequestUserLocation": ".rcs_button_request_user_location",
    "RcsButtonScheduleEvent": ".rcs_button_schedule_event",
    "RcsButtonSendLocation": ".rcs_button_send_location",
    "RcsButtonSendLocationLatLong": ".rcs_button_send_location_lat_long",
    "RcsButtonTrigger": ".rcs_button_trigger",
    "RcsCampaign": ".rcs_campaign",
    "RcsCampaignSchemaAgent": ".rcs_campaign_schema_agent",
    "RcsCampaignSchemaAgentEmailsItem": ".rcs_campaign_schema_agent_emails_item",
    "RcsCampaignSchemaAgentPhonesItem": ".rcs_campaign_schema_agent_phones_item",
    "RcsCampaignSchemaAgentWebsitesItem": ".rcs_campaign_schema_agent_websites_item",
    "RcsCampaignSchemaExtraAgent": ".rcs_campaign_schema_extra_agent",
    "RcsCampaignSchemaExtraAgentEmailsItem": ".rcs_campaign_schema_extra_agent_emails_item",
    "RcsCampaignSchemaExtraAgentPhonesItem": ".rcs_campaign_schema_extra_agent_phones_item",
    "RcsCampaignSchemaExtraAgentWebsitesItem": ".rcs_campaign_schema_extra_agent_websites_item",
    "RcsCampaignSchemaExtraKeywords": ".rcs_campaign_schema_extra_keywords",
    "RcsCampaignSchemaExtraKeywordsHelp": ".rcs_campaign_schema_extra_keywords_help",
    "RcsCampaignSchemaExtraKeywordsOptIn": ".rcs_campaign_schema_extra_keywords_opt_in",
    "RcsCampaignSchemaExtraKeywordsOptOut": ".rcs_campaign_schema_extra_keywords_opt_out",
    "RcsCampaignSchemaExtraLinks": ".rcs_campaign_schema_extra_links",
    "RcsCampaignSchemaExtraTraffic": ".rcs_campaign_schema_extra_traffic",
    "RcsCampaignSchemaExtraUseCase": ".rcs_campaign_schema_extra_use_case",
    "RcsCampaignSchemaKeywords": ".rcs_campaign_schema_keywords",
    "RcsCampaignSchemaKeywordsHelp": ".rcs_campaign_schema_keywords_help",
    "RcsCampaignSchemaKeywordsOptIn": ".rcs_campaign_schema_keywords_opt_in",
    "RcsCampaignSchemaKeywordsOptOut": ".rcs_campaign_schema_keywords_opt_out",
    "RcsCampaignSchemaLinks": ".rcs_campaign_schema_links",
    "RcsCampaignSchemaTraffic": ".rcs_campaign_schema_traffic",
    "RcsCampaignSchemaUseCase": ".rcs_campaign_schema_use_case",
    "RcsCampaignStatus": ".rcs_campaign_status",
    "RcsCampaignUseCaseEnum": ".rcs_campaign_use_case_enum",
    "RcsCapabilitiesResult": ".rcs_capabilities_result",
    "RcsCapability": ".rcs_capability",
    "RcsCapabilityActions": ".rcs_capability_actions",
    "RcsCapabilityCards": ".rcs_capability_cards",
    "RcsCardsContent": ".rcs_cards_content",
    "RcsCardsContentCardsItem": ".rcs_cards_content_cards_item",
    "RcsContent": ".rcs_content",
    "RcsLinkResult": ".rcs_link_result",
    "RcsMediaContent": ".rcs_media_content",
    "RcsMediaDetailsContent": ".rcs_media_details_content",
    "RcsMessagingTypeEnum": ".rcs_messaging_type_enum",
    "RcsValidateContent": ".rcs_validate_content",
    "RcsValidateContentMedia": ".rcs_validate_content_media",
    "RcsValidationResult": ".rcs_validation_result",
    "RcsWhitelistResponse": ".rcs_whitelist_response",
    "ReactionResult": ".reaction_result",
    "RefreshedFile": ".refreshed_file",
    "RichButton": ".rich_button",
    "RichButton_Call": ".rich_button",
    "RichButton_OpenUrl": ".rich_button",
    "RichButton_RequestUserLocation": ".rich_button",
    "RichButton_ScheduleEvent": ".rich_button",
    "RichButton_SendLocation": ".rich_button",
    "RichButton_Trigger": ".rich_button",
    "RichCard": ".rich_card",
    "RichCards": ".rich_cards",
    "RichCardsMessage": ".rich_cards_message",
    "RichMediaMessage": ".rich_media_message",
    "RichMessage": ".rich_message",
    "RichStandaloneCardOptions": ".rich_standalone_card_options",
    "RichText": ".rich_text",
    "RichTextMessage": ".rich_text_message",
    "ScheduleCancelResult": ".schedule_cancel_result",
    "ScheduledBlastDetails": ".scheduled_blast_details",
    "ScheduledBlastResponseConfig": ".scheduled_blast_response_config",
    "ScheduledMessage": ".scheduled_message",
    "ScheduledSendResponseConfig": ".scheduled_send_response_config",
    "SendRcsCardOptionsStandaloneCardImageAlignment": ".send_rcs_card_options_standalone_card_image_alignment",
    "SendRcsCardOptionsStandaloneCardOrientation": ".send_rcs_card_options_standalone_card_orientation",
    "SendRichCardsOptions": ".send_rich_cards_options",
    "SendRichMessageOptions": ".send_rich_message_options",
    "SendSmsResponseSegments": ".send_sms_response_segments",
    "SendSmsResponseSegmentsEncoding": ".send_sms_response_segments_encoding",
    "SendTypingIndicatorResponse": ".send_typing_indicator_response",
    "Sender": ".sender",
    "SentMmsDetails": ".sent_mms_details",
    "SentRichMessage": ".sent_rich_message",
    "SentSmsDetails": ".sent_sms_details",
    "ShortenedUrl": ".shortened_url",
    "ShortenedUrlWithClickData": ".shortened_url_with_click_data",
    "SmsContent": ".sms_content",
    "SmsValidationResponseSegments": ".sms_validation_response_segments",
    "SmsValidationResponseSegmentsGsm7": ".sms_validation_response_segments_gsm_7",
    "SmsValidationResponseSegmentsUtf16": ".sms_validation_response_segments_utf_16",
    "SmsValidationResponseTotal": ".sms_validation_response_total",
    "SmsValidationResult": ".sms_validation_result",
    "SubUseCaseEnum": ".sub_use_case_enum",
    "SubmissionResults": ".submission_results",
    "SuccessfulConversationUpdate": ".successful_conversation_update",
    "TollFreeCampaign": ".toll_free_campaign",
    "TollFreeCampaignSchemaKeywords": ".toll_free_campaign_schema_keywords",
    "TollFreeCampaignSchemaKeywordsHelp": ".toll_free_campaign_schema_keywords_help",
    "TollFreeCampaignSchemaKeywordsOptIn": ".toll_free_campaign_schema_keywords_opt_in",
    "TollFreeCampaignSchemaLinks": ".toll_free_campaign_schema_links",
    "TollFreeCampaignSchemaOptIn": ".toll_free_campaign_schema_opt_in",
    "TollFreeCampaignSchemaOptions": ".toll_free_campaign_schema_options",
    "TollFreeCampaignSchemaUseCase": ".toll_free_campaign_schema_use_case",
    "TollFreeCampaignStatus": ".toll_free_campaign_status",
    "TollFreeCampaignUseCaseEnum": ".toll_free_campaign_use_case_enum",
    "TollFreeCampaignWithExtendedBrandAndStatus": ".toll_free_campaign_with_extended_brand_and_status",
    "TollFreeStatusEnum": ".toll_free_status_enum",
    "TollFreeWithExtendedBrandAndStatusKeywords": ".toll_free_with_extended_brand_and_status_keywords",
    "TollFreeWithExtendedBrandAndStatusKeywordsHelp": ".toll_free_with_extended_brand_and_status_keywords_help",
    "TollFreeWithExtendedBrandAndStatusKeywordsOptIn": ".toll_free_with_extended_brand_and_status_keywords_opt_in",
    "TollFreeWithExtendedBrandAndStatusLinks": ".toll_free_with_extended_brand_and_status_links",
    "TollFreeWithExtendedBrandAndStatusOptIn": ".toll_free_with_extended_brand_and_status_opt_in",
    "TollFreeWithExtendedBrandAndStatusOptions": ".toll_free_with_extended_brand_and_status_options",
    "TollFreeWithExtendedBrandAndStatusUseCase": ".toll_free_with_extended_brand_and_status_use_case",
    "Tracking": ".tracking",
    "UpdatedContactId": ".updated_contact_id",
    "UploadResults": ".upload_results",
    "UserEvent": ".user_event",
    "UserEventConversation": ".user_event_conversation",
    "VCardAddressSchemaTypeItem": ".v_card_address_schema_type_item",
    "VCardData": ".v_card_data",
    "VCardDataFile": ".v_card_data_file",
    "VCardDataFileMetadata": ".v_card_data_file_metadata",
    "VCardEmailSchemaTypeItem": ".v_card_email_schema_type_item",
    "VCardGeo": ".v_card_geo",
    "VCardName": ".v_card_name",
    "VCardOrganization": ".v_card_organization",
    "VCardPhoneSchemaTypeItem": ".v_card_phone_schema_type_item",
    "ValidateCampaignParams": ".validate_campaign_params",
    "ValidationErrorDetails": ".validation_error_details",
    "ValidationResults": ".validation_results",
    "Vcard": ".vcard",
    "VcardAddress": ".vcard_address",
    "VcardContent": ".vcard_content",
    "VcardEmail": ".vcard_email",
    "VcardPhone": ".vcard_phone",
    "VcardResource": ".vcard_resource",
    "VettingFeedback": ".vetting_feedback",
    "VettingHistory": ".vetting_history",
    "VettingHistoryVettingStatus": ".vetting_history_vetting_status",
    "VettingResults": ".vetting_results",
    "WebhookEventEnum": ".webhook_event_enum",
    "WebhookResult": ".webhook_result",
    "Webhooks": ".webhooks",
    "ZodError": ".zod_error",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AdvancedPhoneInformation",
    "AdvancedPhoneInformationCarrier",
    "AdvancedPhoneInformationContact",
    "AdvancedPhoneInformationLocation",
    "AdvancedPhoneInformationLocationCoordinates",
    "AdvancedPhoneInformationLocationCountry",
    "AdvancedPhoneInformationType",
    "AdvancedPhoneInformationTypeRecommendation",
    "Agent",
    "AttachWebhookByIdParams",
    "AttachWebhookParams",
    "AttachWebhookResponseWebhook",
    "AttachedPhoneNumberResult",
    "AudienceCountOnly",
    "AudienceWithPagination",
    "AutofillCampaignParams",
    "AutofillDlcCampaignResponse",
    "AutofillDlcResponseKeywords",
    "AutofillDlcResponseKeywordsHelp",
    "AutofillDlcResponseKeywordsOptIn",
    "AutofillDlcResponseKeywordsOptOut",
    "AutofillDlcResponseLinks",
    "AutofillDlcResponseOptions",
    "AutofillDlcResponseUseCase",
    "BadRequestErrorBody",
    "BaseRichMessage",
    "BasicPhoneInformation",
    "BasicPhoneInformationContact",
    "BasicPhoneInformationLocation",
    "BasicPhoneInformationLocationCountry",
    "BlastDetails",
    "BrandStatus",
    "BrandStatusEnum",
    "ButtonClicked",
    "ButtonClickedData",
    "ButtonClickedDataButton",
    "ButtonClickedDataButtonRaw",
    "ButtonClickedDataButtonType",
    "BuyResponseCapabilities",
    "CampaignEnum",
    "CampaignQuery",
    "CampaignSubmissionResult",
    "CampaignValidationResponseErrorsItem",
    "CampaignValidationResult",
    "CompanyEntityTypeEnum",
    "CompanySectorEnum",
    "CompanyTypeEnum",
    "ConfiguredWebhook",
    "Contact",
    "ContactId",
    "Conversation",
    "ConversationByIdParams",
    "ConversationByParticipantsParams",
    "ConversationContact",
    "ConversationList",
    "ConversationSender",
    "CreateAndAttachWebhookByUrlParams",
    "CreateUrlOptions",
    "DeleteAudienceResponse",
    "DetachedPhoneNumberResult",
    "DetachedWebhookInfo",
    "DetailedPhoneNumberEnum",
    "DlcAssignmentStatusEnum",
    "DlcCampaignStatus",
    "DlcCampaignUseCaseEnum",
    "DlcCampaignWithExtendedBrandAndStatus",
    "DlcWithExtendedBrandAndStatusKeywords",
    "DlcWithExtendedBrandAndStatusKeywordsHelp",
    "DlcWithExtendedBrandAndStatusKeywordsOptIn",
    "DlcWithExtendedBrandAndStatusKeywordsOptOut",
    "DlcWithExtendedBrandAndStatusLinks",
    "DlcWithExtendedBrandAndStatusMnoBrandTier",
    "DlcWithExtendedBrandAndStatusMnoTcrTier",
    "DlcWithExtendedBrandAndStatusOptions",
    "DlcWithExtendedBrandAndStatusUseCase",
    "EnhancedContact",
    "EnhancedContactItem",
    "Error",
    "ExtendedBrand",
    "ExtendedBrandWithVetting",
    "ExtendedRcsCampaign",
    "GetConversationParams",
    "GetDlcCampaignStatusResponseUpdates",
    "GetTollFreeCampaignStatusResponseUpdates",
    "LinkClickEvent",
    "LocationShareAction",
    "LocationShareActionData",
    "Message",
    "MessageContent",
    "MessageEvent",
    "MessageEventContent",
    "MessageEventConversation",
    "MessageEventDirection",
    "MessageEventMmsContent",
    "MessageEventRcsButtonData",
    "MessageEventRcsCardsContent",
    "MessageEventRcsCardsContentCardsItem",
    "MessageEventRcsLocationData",
    "MessageEventRcsMediaContent",
    "MessageEventRcsTextContent",
    "MessageEventSmsContent",
    "MessageList",
    "MessageMethodEnum",
    "MessageProtocolEnum",
    "MessageSchedule",
    "MessageStatusEnum",
    "MessageVolumeEnum",
    "MessageWithReaction",
    "MessageWithReactionDirection",
    "MessagingProfileEnum",
    "MmsContent",
    "MmsValidationResponseSegments",
    "MmsValidationResponseSegmentsValueItem",
    "MmsValidationResult",
    "NotFoundErrorBody",
    "NumberFormat",
    "OptInMethodEnum",
    "OptionalBrandInfo",
    "OptionalContact",
    "OptionalContacts",
    "Pagination",
    "Phone",
    "PhoneCapabilities",
    "PhoneEnum",
    "PhoneFeatureEnum",
    "PhoneNumberCampaignAttachFailedItem",
    "PhoneNumberCampaignAttachPhoneNumbersItem",
    "PhoneNumberCampaignAttachPhoneNumbersItemCampaign",
    "PhoneNumberCampaignDetachFailedItem",
    "PhoneNumberCampaignDetachPhoneNumbersItem",
    "PhoneNumberCampaignDetachPhoneNumbersItemCampaign",
    "PhoneNumberCost",
    "PhoneNumberDetails",
    "PhoneNumberEnum",
    "PhoneNumberRegion",
    "PhoneNumberStatus",
    "PhoneNumberStatusEnum",
    "PinnacleFileUploadMetadata",
    "PinnacleUrlConfig",
    "ProfileStatusEnum",
    "PurchasedNumber",
    "RcsButtonCall",
    "RcsButtonOpenUrl",
    "RcsButtonOpenUrlWebviewMode",
    "RcsButtonRequestUserLocation",
    "RcsButtonScheduleEvent",
    "RcsButtonSendLocation",
    "RcsButtonSendLocationLatLong",
    "RcsButtonTrigger",
    "RcsCampaign",
    "RcsCampaignSchemaAgent",
    "RcsCampaignSchemaAgentEmailsItem",
    "RcsCampaignSchemaAgentPhonesItem",
    "RcsCampaignSchemaAgentWebsitesItem",
    "RcsCampaignSchemaExtraAgent",
    "RcsCampaignSchemaExtraAgentEmailsItem",
    "RcsCampaignSchemaExtraAgentPhonesItem",
    "RcsCampaignSchemaExtraAgentWebsitesItem",
    "RcsCampaignSchemaExtraKeywords",
    "RcsCampaignSchemaExtraKeywordsHelp",
    "RcsCampaignSchemaExtraKeywordsOptIn",
    "RcsCampaignSchemaExtraKeywordsOptOut",
    "RcsCampaignSchemaExtraLinks",
    "RcsCampaignSchemaExtraTraffic",
    "RcsCampaignSchemaExtraUseCase",
    "RcsCampaignSchemaKeywords",
    "RcsCampaignSchemaKeywordsHelp",
    "RcsCampaignSchemaKeywordsOptIn",
    "RcsCampaignSchemaKeywordsOptOut",
    "RcsCampaignSchemaLinks",
    "RcsCampaignSchemaTraffic",
    "RcsCampaignSchemaUseCase",
    "RcsCampaignStatus",
    "RcsCampaignUseCaseEnum",
    "RcsCapabilitiesResult",
    "RcsCapability",
    "RcsCapabilityActions",
    "RcsCapabilityCards",
    "RcsCardsContent",
    "RcsCardsContentCardsItem",
    "RcsContent",
    "RcsLinkResult",
    "RcsMediaContent",
    "RcsMediaDetailsContent",
    "RcsMessagingTypeEnum",
    "RcsValidateContent",
    "RcsValidateContentMedia",
    "RcsValidationResult",
    "RcsWhitelistResponse",
    "ReactionResult",
    "RefreshedFile",
    "RichButton",
    "RichButton_Call",
    "RichButton_OpenUrl",
    "RichButton_RequestUserLocation",
    "RichButton_ScheduleEvent",
    "RichButton_SendLocation",
    "RichButton_Trigger",
    "RichCard",
    "RichCards",
    "RichCardsMessage",
    "RichMediaMessage",
    "RichMessage",
    "RichStandaloneCardOptions",
    "RichText",
    "RichTextMessage",
    "ScheduleCancelResult",
    "ScheduledBlastDetails",
    "ScheduledBlastResponseConfig",
    "ScheduledMessage",
    "ScheduledSendResponseConfig",
    "SendRcsCardOptionsStandaloneCardImageAlignment",
    "SendRcsCardOptionsStandaloneCardOrientation",
    "SendRichCardsOptions",
    "SendRichMessageOptions",
    "SendSmsResponseSegments",
    "SendSmsResponseSegmentsEncoding",
    "SendTypingIndicatorResponse",
    "Sender",
    "SentMmsDetails",
    "SentRichMessage",
    "SentSmsDetails",
    "ShortenedUrl",
    "ShortenedUrlWithClickData",
    "SmsContent",
    "SmsValidationResponseSegments",
    "SmsValidationResponseSegmentsGsm7",
    "SmsValidationResponseSegmentsUtf16",
    "SmsValidationResponseTotal",
    "SmsValidationResult",
    "SubUseCaseEnum",
    "SubmissionResults",
    "SuccessfulConversationUpdate",
    "TollFreeCampaign",
    "TollFreeCampaignSchemaKeywords",
    "TollFreeCampaignSchemaKeywordsHelp",
    "TollFreeCampaignSchemaKeywordsOptIn",
    "TollFreeCampaignSchemaLinks",
    "TollFreeCampaignSchemaOptIn",
    "TollFreeCampaignSchemaOptions",
    "TollFreeCampaignSchemaUseCase",
    "TollFreeCampaignStatus",
    "TollFreeCampaignUseCaseEnum",
    "TollFreeCampaignWithExtendedBrandAndStatus",
    "TollFreeStatusEnum",
    "TollFreeWithExtendedBrandAndStatusKeywords",
    "TollFreeWithExtendedBrandAndStatusKeywordsHelp",
    "TollFreeWithExtendedBrandAndStatusKeywordsOptIn",
    "TollFreeWithExtendedBrandAndStatusLinks",
    "TollFreeWithExtendedBrandAndStatusOptIn",
    "TollFreeWithExtendedBrandAndStatusOptions",
    "TollFreeWithExtendedBrandAndStatusUseCase",
    "Tracking",
    "UpdatedContactId",
    "UploadResults",
    "UserEvent",
    "UserEventConversation",
    "VCardAddressSchemaTypeItem",
    "VCardData",
    "VCardDataFile",
    "VCardDataFileMetadata",
    "VCardEmailSchemaTypeItem",
    "VCardGeo",
    "VCardName",
    "VCardOrganization",
    "VCardPhoneSchemaTypeItem",
    "ValidateCampaignParams",
    "ValidationErrorDetails",
    "ValidationResults",
    "Vcard",
    "VcardAddress",
    "VcardContent",
    "VcardEmail",
    "VcardPhone",
    "VcardResource",
    "VettingFeedback",
    "VettingHistory",
    "VettingHistoryVettingStatus",
    "VettingResults",
    "WebhookEventEnum",
    "WebhookResult",
    "Webhooks",
    "ZodError",
]
